<?php
// Post term options
$post_term_options = etc_get_grid_term_options('post');

// Register Post Grid Widget
etc_add_custom_widget(
    array(
        'name' => 'cms_post_list',
        'title' => esc_html__( 'CMS Post List', 'frontline' ),
        'icon' => 'eicon-post-list',
        'categories' => array( Elementor_Theme_Core::ETC_CATEGORY_NAME ),
        'scripts' => [
            'imagesloaded',
            'isotope',
            'cms-post-grid-widget-js',
        ],
        'params' => array(
            'sections' => array(
                array(
                    'name' => 'layout_section',
                    'label' => esc_html__( 'Layout', 'frontline' ),
                    'tab' => \Elementor\Controls_Manager::TAB_LAYOUT,
                    'controls' => array(
                        array(
                            'name' => 'layout',
                            'label' => esc_html__( 'Templates', 'frontline' ),
                            'type' => Elementor_Theme_Core::LAYOUT_CONTROL,
                            'default' => '1',
                            'options' => [
                                '1' => [
                                    'label' => esc_html__( 'Layout 1', 'frontline' ),
                                    'image' => get_template_directory_uri() . '/elementor/templates/widgets/cms_post_list/layout-image/layout1.jpg'
                                ],
                            ],
                        ),
                    ),
                ),
                array(
                    'name' => 'source_section',
                    'label' => esc_html__( 'Source', 'frontline' ),
                    'tab' => \Elementor\Controls_Manager::TAB_CONTENT,
                    'controls' => array(
                        array(
                            'name' => 'categories',
                            'label' => esc_html__( 'Select Categories', 'frontline' ),
                            'type' => \Elementor\Controls_Manager::SELECT2,
                            'multiple' => true,
                            'options' => $post_term_options,
                        ),
                        array(
                            'name' => 'orderby',
                            'label' => esc_html__( 'Order By', 'frontline' ),
                            'type' => \Elementor\Controls_Manager::SELECT,
                            'default' => 'date',
                            'options' => [
                                'date' => esc_html__( 'Date', 'frontline' ),
                                'ID' => esc_html__( 'ID', 'frontline' ),
                                'author' => esc_html__( 'Author', 'frontline' ),
                                'title' => esc_html__( 'Title', 'frontline' ),
                                'rand' => esc_html__( 'Random', 'frontline' ),
                            ],
                        ),
                        array(
                            'name' => 'order',
                            'label' => esc_html__( 'Sort Order', 'frontline' ),
                            'type' => \Elementor\Controls_Manager::SELECT,
                            'default' => 'desc',
                            'options' => [
                                'desc' => esc_html__( 'Descending', 'frontline' ),
                                'asc' => esc_html__( 'Ascending', 'frontline' ),
                            ],
                        ),
                        array(
                            'name' => 'limit',
                            'label' => esc_html__( 'Total items', 'frontline' ),
                            'type' => \Elementor\Controls_Manager::NUMBER,
                            'default' => '6',
                        ),
                    ),
                ),
                array(
                    'name' => 'display_section',
                    'label' => esc_html__( 'Display Options', 'frontline' ),
                    'tab' => \Elementor\Controls_Manager::TAB_CONTENT,
                    'controls' => array(
                        array(
                            'name' => 'show_thumbnail',
                            'label' => esc_html__( 'Show Thumbnail', 'frontline' ),
                            'type' => \Elementor\Controls_Manager::SWITCHER,
                            'default' => 'true',
                        ),
                        array(
                            'name' => 'social_share',
                            'label' => esc_html__( 'Social Share', 'frontline' ),
                            'type' => \Elementor\Controls_Manager::SWITCHER,
                            'default' => 'true',
                        ),
                        array(
                            'name' => 'thumbnail',
                            'type' => \Elementor\Group_Control_Image_Size::get_type(),
                            'control_type' => 'group',
                            'default' => 'full',
                        ),
                        array(
                            'name' => 'num_words',
                            'label' => esc_html__( 'Number of Words', 'frontline' ),
                            'type' => \Elementor\Controls_Manager::NUMBER,
                            'default' => 36,
                            'separator' => 'before',
                        ),
                        array(
                            'name' => 'button_text',
                            'label' => esc_html__( 'Button Text', 'frontline' ),
                            'type' => \Elementor\Controls_Manager::TEXT,
                            'default' => esc_html__('Read more', 'frontline'),
                        ),
                        array(
                            'name' => 'pagination_type',
                            'label' => esc_html__( 'Pagination Type', 'frontline' ),
                            'type' => \Elementor\Controls_Manager::SELECT,
                            'default' => 'false',
                            'options' => [
                                'pagination' => esc_html__( 'Pagination', 'frontline' ),
                                'loadmore' => esc_html__( 'Loadmore', 'frontline' ),
                                'false' => esc_html__( 'Disable', 'frontline' ),
                            ]
                        ),
                    ),
                ),
            ),
        ),
    ),
    get_template_directory() . '/elementor/core/widgets/'
);