<?php
/**
 * Functions which enhance the theme by hooking into WordPress
 *
 * @package Frontline
 */

/*
 * Get page ID by Slug
*/
function frontline_get_id_by_slug($slug, $post_type){
    $content = get_page_by_path($slug, OBJECT, $post_type);
    $id = $content->ID;
    return $id;
}

/**
 * Get content by slug
 **/
function frontline_get_content_by_slug($slug, $post_type){
    $content = get_posts(
        array(
            'name'      => $slug,
            'post_type' => $post_type
        )
    );
    if(!empty($content))
        return $content[0]->post_content;
    else
        return;
}

/**
 * Show content by slug
 **/
if(!function_exists('frontline_content_by_slug')){
    function frontline_content_by_slug($slug, $post_type){
        $content = frontline_get_content_by_slug($slug, $post_type);

        $id = frontline_get_id_by_slug($slug, $post_type);
        $shortcodes_custom_css = get_post_meta( $id, '_wpb_shortcodes_custom_css', true );
        if ( ! empty( $shortcodes_custom_css ) ) {
            $shortcodes_custom_css = strip_tags( $shortcodes_custom_css );
            echo '<style data-type="vc_shortcodes-custom-css">';
            echo esc_html($shortcodes_custom_css);
            echo '</style>';
        }

        echo apply_filters('the_content',  $content);
    }
}
/**
 * Setup default image sizes after the theme has been activated
 */
function frontline_after_setup_theme()
{

}
add_action( 'after_setup_theme', 'frontline_after_setup_theme' );

/**
 * Adds custom classes to the array of body classes.
 *
 * @param array $classes Classes for the body element.
 * @return array
 */
function frontline_body_classes( $classes )
{   
    // Adds a class of group-blog to blogs with more than 1 published author.
    if (is_multi_author()) {
        $classes[] = 'group-blog';
    }

    // Adds a class of hfeed to non-singular pages.
    if (!is_singular()) {
        $classes[] = 'hfeed';
    }

    if (frontline_get_opt( 'site_boxed', false )) {
        $classes[] = 'site-boxed';
    }

    if ( class_exists('WPBakeryVisualComposerAbstract') ) {
        $classes[] = 'visual-composer';
    }

    if (class_exists('ReduxFramework')) {
        $classes[] = 'redux-page';
    }

    $body_default_font = frontline_get_opt( 'body_default_font', 'Futura' );
    $heading_default_font = frontline_get_opt( 'heading_default_font', 'Playfair Display' );
    $sub_heading_default_font = frontline_get_opt( 'sub_heading_default_font', 'Shadows-Into-Light' );

    if($body_default_font == 'Futura') {
        $classes[] = 'body-default-font';
    }

    if($heading_default_font == 'Playfair Display') {
        $classes[] = 'heading-default-font';
    }

    if (frontline_get_opt( 'sticky_on', false )) {
        $classes[] = 'header-sticky';
    }

    return $classes;
}
add_filter( 'body_class', 'frontline_body_classes' );


/**
 * Add a pingback url auto-discovery header for singularly identifiable articles.
 */
function frontline_pingback_header()
{
    if ( is_singular() && pings_open() )
    {
        echo '<link rel="pingback" href="', esc_url( get_bloginfo( 'pingback_url' ) ), '">';
    }
}
add_action( 'wp_head', 'frontline_pingback_header' );
