<?php
/**
 * Register metabox for posts based on Redux Framework. Supported methods:
 *     isset_args( $post_type )
 *     set_args( $post_type, $redux_args, $metabox_args )
 *     add_section( $post_type, $sections )
 * Each post type can contains only one metabox. Pease note that each field id
 * leads by an underscore sign ( _ ) in order to not show that into Custom Field
 * Metabox from WordPress core feature.
 *
 * @param  CMS_Post_Metabox $metabox
 */

add_action( 'cms_post_metabox_register', 'frontline_page_options_register' );

function frontline_page_options_register( $metabox ) {

    if (class_exists('WPCF7')) {
        $cf7 = get_posts('post_type="wpcf7_contact_form"&numberposts=-1');

        $contact_forms = array();
        if ($cf7) {
            foreach ($cf7 as $cform) {
                $contact_forms[$cform->ID] = $cform->post_title;
            }
        } else {
            $contact_forms[esc_html__('No contact forms found', 'frontline')] = 0;
        }
    } else {
        $contact_forms = '';
    }

	if ( ! $metabox->isset_args( 'post' ) ) {
		$metabox->set_args( 'post', array(
			'opt_name'            => 'post_option',
			'display_name'        => esc_html__( 'Post Settings', 'frontline' ),
			'show_options_object' => false,
		), array(
			'context'  => 'advanced',
			'priority' => 'default'
		) );
	}

	if ( ! $metabox->isset_args( 'product' ) ) {
		$metabox->set_args( 'product', array(
			'opt_name'            => 'product_option',
			'display_name'        => esc_html__( 'Product Settings', 'frontline' ),
			'show_options_object' => false,
		), array(
			'context'  => 'advanced',
			'priority' => 'default'
		) );
	}

	if ( ! $metabox->isset_args( 'page' ) ) {
		$metabox->set_args( 'page', array(
			'opt_name'            => frontline_get_page_opt_name(),
			'display_name'        => esc_html__( 'Page Settings', 'frontline' ),
			'show_options_object' => false,
		), array(
			'context'  => 'advanced',
			'priority' => 'default'
		) );
	}

	if ( ! $metabox->isset_args( 'cms_pf_audio' ) ) {
		$metabox->set_args( 'cms_pf_audio', array(
			'opt_name'     => 'post_format_audio',
			'display_name' => esc_html__( 'Audio', 'frontline' ),
			'class'        => 'fully-expanded',
		), array(
			'context'  => 'advanced',
			'priority' => 'default'
		) );
	}

	if ( ! $metabox->isset_args( 'cms_pf_link' ) ) {
		$metabox->set_args( 'cms_pf_link', array(
			'opt_name'     => 'post_format_link',
			'display_name' => esc_html__( 'Link', 'frontline' )
		), array(
			'context'  => 'advanced',
			'priority' => 'default'
		) );
	}

	if ( ! $metabox->isset_args( 'cms_pf_quote' ) ) {
		$metabox->set_args( 'cms_pf_quote', array(
			'opt_name'     => 'post_format_quote',
			'display_name' => esc_html__( 'Quote', 'frontline' )
		), array(
			'context'  => 'advanced',
			'priority' => 'default'
		) );
	}

	if ( ! $metabox->isset_args( 'cms_pf_video' ) ) {
		$metabox->set_args( 'cms_pf_video', array(
			'opt_name'     => 'post_format_video',
			'display_name' => esc_html__( 'Video', 'frontline' ),
			'class'        => 'fully-expanded',
		), array(
			'context'  => 'advanced',
			'priority' => 'default'
		) );
	}

	if ( ! $metabox->isset_args( 'cms_pf_gallery' ) ) {
		$metabox->set_args( 'cms_pf_gallery', array(
			'opt_name'     => 'post_format_gallery',
			'display_name' => esc_html__( 'Gallery', 'frontline' ),
			'class'        => 'fully-expanded',
		), array(
			'context'  => 'advanced',
			'priority' => 'default'
		) );
	}

    /* Extra Post Type */
    if ( ! $metabox->isset_args( 'portfolio' ) ) {
        $metabox->set_args( 'portfolio', array(
            'opt_name'            => 'portfolio_option',
            'display_name'        => esc_html__( 'Case Study Settings', 'frontline' ),
            'show_options_object' => false,
        ), array(
            'context'  => 'advanced',
            'priority' => 'default'
        ) );
    }

    if ( ! $metabox->isset_args( 'area' ) ) {
        $metabox->set_args( 'area', array(
            'opt_name'            => 'area_option',
            'display_name'        => esc_html__( 'Practice Area Settings', 'frontline' ),
            'show_options_object' => false,
        ), array(
            'context'  => 'advanced',
            'priority' => 'default'
        ) );
    }

    if ( ! $metabox->isset_args( 'attorney' ) ) {
        $metabox->set_args( 'attorney', array(
            'opt_name'            => 'attorney_option',
            'display_name'        => esc_html__( 'Attorney Settings', 'frontline' ),
            'show_options_object' => false,
        ), array(
            'context'  => 'advanced',
            'priority' => 'default'
        ) );
    }

	/**
	 * Config post meta options
	 *
	 */
	$metabox->add_section( 'post', array(
		'title'  => esc_html__( 'Post Settings', 'frontline' ),
		'icon'   => 'el el-refresh',
		'fields' => array(
			array(
				'id'             => 'post_content_padding',
				'type'           => 'spacing',
				'output'         => array( '.single-post #content' ),
				'right'          => false,
				'left'           => false,
				'mode'           => 'padding',
				'units'          => array( 'px' ),
				'units_extended' => 'false',
				'title'          => esc_html__( 'Content Padding', 'frontline' ),
				'subtitle'     => esc_html__( 'Content site paddings.', 'frontline' ),
				'desc'           => esc_html__( 'Default: Theme Option.', 'frontline' ),
				'default'        => array(
					'padding-top'    => '',
					'padding-bottom' => '',
					'units'          => 'px',
				)
			),
		)
	) );

	/**
	 * Config page meta options
	 *
	 */
	$metabox->add_section( 'page', array(
		'title'  => esc_html__( 'Header', 'frontline' ),
		'desc'   => esc_html__( 'Header settings for the page.', 'frontline' ),
		'icon'   => 'el-icon-website',
		'fields' => array(
			array(
				'id'      => 'custom_header',
				'type'    => 'switch',
				'title'   => esc_html__( 'Custom Header', 'frontline' ),
				'default' => false,
				'indent'  => true
			),
			array(
				'id'           => 'header_layout',
				'type'         => 'image_select',
				'title'        => esc_html__( 'Layout', 'frontline' ),
				'subtitle'     => esc_html__( 'Select a layout for header.', 'frontline' ),
				'options'      => array(
					'0' => get_template_directory_uri() . '/assets/images/header-layout/h0.jpg',
					'1' => get_template_directory_uri() . '/assets/images/header-layout/h1.jpg',
					'2' => get_template_directory_uri() . '/assets/images/header-layout/h2.jpg',
					'3' => get_template_directory_uri() . '/assets/images/header-layout/h3.jpg',
					'4' => get_template_directory_uri() . '/assets/images/header-layout/h4.jpg',
                    '5' => get_template_directory_uri() . '/assets/images/header-layout/h5.jpg',
                    '6' => get_template_directory_uri() . '/assets/images/header-layout/h6.jpg',
                    '7' => get_template_directory_uri() . '/assets/images/header-layout/h7.jpg',
				),
				'default'      => frontline_get_option_of_theme_options( 'header_layout' ),
				'required'     => array( 0 => 'custom_header', 1 => 'equals', 2 => '1' ),
				'force_output' => true
			),
			array(
	            'id'       => 'logo_dark',
	            'type'     => 'media',
	            'title'    => esc_html__('Logo Dark', 'frontline'),
	            'default' => '',
	            'required'     => array( 0 => 'custom_header', 1 => 'equals', 2 => '1' ),
				'force_output' => true
	        ),
		)
	) );

	$metabox->add_section( 'page', array(
		'title'  => esc_html__( 'Page Title', 'frontline' ),
		'icon'   => 'el el-indent-left',
		'fields' => array(
			array(
				'id'           => 'custom_pagetitle',
				'type'         => 'button_set',
				'title'        => esc_html__( 'Page Title', 'frontline' ),
				'options'      => array(
					'themeoption'  => esc_html__( 'Theme Option', 'frontline' ),
					'show'  => esc_html__( 'Custom', 'frontline' ),
					'hide'  => esc_html__( 'Hide', 'frontline' ),
				),
				'default'      => 'themeoption',
			),

			array(
	            'id'       => 'ptitle_layout',
	            'type'     => 'image_select',
	            'title'    => esc_html__('Layout', 'frontline'),
	            'subtitle' => esc_html__('Select a layout for page title.', 'frontline'),
	            'options'  => array(
	                '' => get_template_directory_uri() . '/assets/images/ptitle-layout/p0.jpg',
	                '1' => get_template_directory_uri() . '/assets/images/ptitle-layout/p1.jpg',
                    '2' => get_template_directory_uri() . '/assets/images/ptitle-layout/p2.jpg',
	            ),
	            'default'  => '',
	            'required'     => array( 0 => 'custom_pagetitle', 1 => '=', 2 => 'show' ),
				'force_output' => true
	        ),

			array(
				'id'           => 'custom_title',
				'type'         => 'text',
				'title'        => esc_html__( 'Title', 'frontline' ),
				'subtitle'     => esc_html__( 'Use custom title for this page. The default title will be used on document title.', 'frontline' ),
				'required'     => array( 0 => 'custom_pagetitle', 1 => '=', 2 => 'show' ),
				'force_output' => true
			),
			array(
				'id'           => 'sub_title',
				'type'         => 'text',
				'title'        => esc_html__( 'Sub Title', 'frontline' ),
				'required'     => array( 0 => 'custom_pagetitle', 1 => '=', 2 => 'show' ),
				'force_output' => true
			),
			array(
	            'id'       => 'ptitle_bg',
	            'type'     => 'background',
	            'background-color'     => false,
	            'background-repeat'     => false,
	            'background-size'     => false,
	            'background-attachment'     => false,
	            'background-position'     => false,
	            'title'    => esc_html__('Background', 'frontline'),
	            'subtitle' => esc_html__('Page title background image.', 'frontline'),
	            'required'     => array( 0 => 'custom_pagetitle', 1 => '=', 2 => 'show' ),
				'force_output' => true
	        ),
	        array(
	            'id'             => 'ptitle_padding',
	            'type'           => 'spacing',
	            'output'         => array('.site #pagetitle.page-title'),
	            'right'   => false,
	            'left'    => false,
	            'mode'           => 'padding',
	            'units'          => array('px'),
	            'units_extended' => 'false',
	            'title'          => esc_html__('Page Title Padding', 'frontline'),
	            'desc'           => esc_html__('Default: Top 144px, Bottom 132px', 'frontline'),
	            'default'            => array(
	                'padding-top'   => '',
	                'padding-bottom'   => '',
	                'units'          => 'px',
	            ),
	            'required'     => array( 0 => 'custom_pagetitle', 1 => '=', 2 => 'show' ),
				'force_output' => true
	        ),
		)
	) );

	$metabox->add_section( 'page', array(
		'title'  => esc_html__( 'Content', 'frontline' ),
		'desc'   => esc_html__( 'Settings for content area.', 'frontline' ),
		'icon'   => 'el-icon-pencil',
		'fields' => array(
			array(
				'id'       => 'content_bg_color',
				'type'     => 'color_rgba',
				'title'    => esc_html__( 'Background Color', 'frontline' ),
				'subtitle' => esc_html__( 'Content background color.', 'frontline' ),
				'output'   => array( 'background-color' => 'body' )
			),
			array(
				'id'             => 'content_padding',
				'type'           => 'spacing',
				'output'         => array( '#content' ),
				'right'          => false,
				'left'           => false,
				'mode'           => 'padding',
				'units'          => array( 'px' ),
				'units_extended' => 'false',
				'title'          => esc_html__( 'Content Padding', 'frontline' ),
				'desc'           => esc_html__( 'Default: Theme Option.', 'frontline' ),
				'default'        => array(
					'padding-top'    => '',
					'padding-bottom' => '',
					'units'          => 'px',
				)
			),
			array(
				'id'      => 'show_sidebar_page',
				'type'    => 'switch',
				'title'   => esc_html__( 'Show Sidebar', 'frontline' ),
				'default' => false,
				'indent'  => true
			),
			array(
				'id'           => 'sidebar_page_pos',
				'type'         => 'button_set',
				'title'        => esc_html__( 'Sidebar Position', 'frontline' ),
				'options'      => array(
					'left'  => esc_html__( 'Left', 'frontline' ),
					'right' => esc_html__( 'Right', 'frontline' ),
				),
				'default'      => 'right',
				'required'     => array( 0 => 'show_sidebar_page', 1 => '=', 2 => '1' ),
				'force_output' => true
			),
		)
	) );

    $metabox->add_section('page', array(
        'title' => esc_html__('Footer', 'frontline'),
        'desc' => esc_html__('Settings for page footer.', 'frontline'),
        'icon' => 'el el-website',
        'fields' => array(
            array(
                'id'      => 'custom_footer',
                'type'    => 'switch',
                'title'   => esc_html__( 'Custom Footer', 'frontline' ),
                'default' => false,
                'indent'  => true
            ),
            array(
                'id'       => 'footer_layout',
                'type'     => 'button_set',
                'title'    => esc_html__('Layout', 'frontline'),
                'subtitle' => esc_html__('Select a layout for upper footer area.', 'frontline'),
                'options'  => array(
                    '1'  => esc_html__('Default', 'frontline'),
                    'custom'  => esc_html__('Custom', 'frontline'),
                    '0'  => esc_html__('No footer', 'frontline'),

                ),
                'default'  => '1',
                'required' => array( 0 => 'custom_footer', 1 => 'equals', 2 => '1' ),
                'force_output' => true
            ),
            array(
                'id'          => 'footer_layout_custom',
                'type'        => 'select',
                'title'       => esc_html__('Custom Layout', 'frontline'),
                'desc'        => sprintf(esc_html__('To use this Option please %sClick Here%s to add your custom footer layout first.','frontline'),'<a href="' . esc_url( admin_url( 'edit.php?post_type=footer' ) ) . '">','</a>'),
                'options'     => frontline_list_post('footer'),
                'default'     => '',
                'required' => array( 0 => 'footer_layout', 1 => 'equals', 2 => 'custom' ),
                'force_output' => true
            ),
            array(
                'id' => 'footer_top_bg',
                'type' => 'background',
                'title' => esc_html__('Footer Top Background', 'frontline'),
                'default' => '',
                'output' => array('#colophon .top-footer'),
                'background-repeat' => false,
                'background-size' => false,
                'background-image' => false,
                'background-attachment' => false,
                'background-position' => false,
                'preview' => false,
                'required' => array(0 => 'custom_footer', 1 => '=', 2 => '1'),
                'force_output' => true
            ),
            array(
                'id' => 'footer_bottom_bg',
                'type' => 'background',
                'title' => esc_html__('Footer Bottom Background', 'frontline'),
                'default' => '',
                'output' => array('#colophon .bottom-footer'),
                'background-repeat' => false,
                'background-size' => false,
                'background-image' => false,
                'background-attachment' => false,
                'background-position' => false,
                'preview' => false,
                'required' => array(0 => 'custom_footer', 1 => '=', 2 => '1'),
                'force_output' => true
            ),
            array(
                'id' => 'footer_separate',
                'type' => 'color',
                'title' => esc_html__('Separate color', 'frontline'),
                'subtitle' => esc_html__('Separate between top and bottom footer', 'frontline'),
                'default' => '',
                'output' => array('border-top-color' => '#colophon .bottom-col'),
                'force_output' => true,
                'required' => array(0 => 'custom_footer', 1 => '=', 2 => '1'),
            ),
            array(
                'id' => 'footer_bg',
                'type' => 'background',
                'title' => esc_html__('Background', 'frontline'),
                'subtitle' => esc_html__('Footer background.', 'frontline'),
                'default' => '',
                'output' => array('.site-footer'),
                'background-color' => false,
                'required' => array(0 => 'custom_footer', 1 => '=', 2 => '1'),
                'force_output' => true
            ),
        )
    ));

	$metabox->add_section( 'product', array(
		'title'  => esc_html__( 'Header', 'frontline' ),
		'desc'   => esc_html__( 'Header settings for the page.', 'frontline' ),
		'icon'   => 'el-icon-website',
		'fields' => array(
			array(
				'id'      => 'custom_header',
				'type'    => 'switch',
				'title'   => esc_html__( 'Custom Header', 'frontline' ),
				'default' => false,
				'indent'  => true
			),
			array(
				'id'           => 'header_layout',
				'type'         => 'image_select',
				'title'        => esc_html__( 'Layout', 'frontline' ),
				'subtitle'     => esc_html__( 'Select a layout for header.', 'frontline' ),
				'options'      => array(
					'0' => get_template_directory_uri() . '/assets/images/header-layout/h0.jpg',
					'1' => get_template_directory_uri() . '/assets/images/header-layout/h1.jpg',
					'2' => get_template_directory_uri() . '/assets/images/header-layout/h2.jpg',
					'3' => get_template_directory_uri() . '/assets/images/header-layout/h3.jpg',
					'4' => get_template_directory_uri() . '/assets/images/header-layout/h4.jpg',
				),
				'default'      => frontline_get_option_of_theme_options( 'header_layout' ),
				'required'     => array( 0 => 'custom_header', 1 => 'equals', 2 => '1' ),
				'force_output' => true
			),
		)
	) );

	$metabox->add_section( 'product', array(
		'title'  => esc_html__( 'Page Title', 'frontline' ),
		'icon'   => 'el el-indent-left',
		'fields' => array(
			array(
				'id'           => 'custom_pagetitle',
				'type'         => 'button_set',
				'title'        => esc_html__( 'Page Title', 'frontline' ),
				'options'      => array(
					'themeoption'  => esc_html__( 'Theme Option', 'frontline' ),
					'show'  => esc_html__( 'Custom', 'frontline' ),
					'hide'  => esc_html__( 'Hide', 'frontline' ),
				),
				'default'      => 'themeoption',
			),
			array(
	            'id'       => 'ptitle_layout',
	            'type'     => 'image_select',
	            'title'    => esc_html__('Layout', 'frontline'),
	            'subtitle' => esc_html__('Select a layout for page title.', 'frontline'),
	            'options'  => array(
	                '' => get_template_directory_uri() . '/assets/images/ptitle-layout/p0.jpg',
	                '1' => get_template_directory_uri() . '/assets/images/ptitle-layout/p1.jpg',
	                '2' => get_template_directory_uri() . '/assets/images/ptitle-layout/p2.jpg',
	            ),
	            'default'  => '',
	            'required'     => array( 0 => 'custom_pagetitle', 1 => '=', 2 => 'show' ),
				'force_output' => true
	        ),
			array(
				'id'           => 'sub_title',
				'type'         => 'text',
				'title'        => esc_html__( 'Sub Title', 'frontline' ),
				'required'     => array( 0 => 'custom_pagetitle', 1 => '=', 2 => 'show' ),
				'force_output' => true
			),
			array(
	            'id'       => 'ptitle_bg',
	            'type'     => 'background',
	            'background-color'     => false,
	            'background-repeat'     => false,
	            'background-size'     => false,
	            'background-attachment'     => false,
	            'background-position'     => false,
	            'title'    => esc_html__('Background', 'frontline'),
	            'subtitle' => esc_html__('Page title background image.', 'frontline'),
	            'required'     => array( 0 => 'custom_pagetitle', 1 => '=', 2 => 'show' ),
				'force_output' => true
	        ),
		)
	) );

	/**
	 * Config post format meta options
	 *
	 */

	$metabox->add_section( 'cms_pf_video', array(
		'title'  => esc_html__( 'Video', 'frontline' ),
		'fields' => array(
			array(
				'id'    => 'post-video-url',
				'type'  => 'text',
				'title' => esc_html__( 'Video URL', 'frontline' ),
				'desc'  => esc_html__( 'YouTube or Vimeo video URL', 'frontline' )
			),

			array(
				'id'    => 'post-video-file',
				'type'  => 'editor',
				'title' => esc_html__( 'Video Upload', 'frontline' ),
				'desc'  => esc_html__( 'Upload video file', 'frontline' )
			),

			array(
				'id'    => 'post-video-html',
				'type'  => 'textarea',
				'title' => esc_html__( 'Embedded video', 'frontline' ),
				'desc'  => esc_html__( 'Use this option when the video does not come from YouTube or Vimeo', 'frontline' )
			)
		)
	) );

	$metabox->add_section( 'cms_pf_gallery', array(
		'title'  => esc_html__( 'Gallery', 'frontline' ),
		'fields' => array(
			array(
				'id'       => 'post-gallery-lightbox',
				'type'     => 'switch',
				'title'    => esc_html__( 'Lightbox?', 'frontline' ),
				'subtitle' => esc_html__( 'Enable lightbox for gallery images.', 'frontline' ),
				'default'  => true
			),
			array(
				'id'       => 'post-gallery-images',
				'type'     => 'gallery',
				'title'    => esc_html__( 'Gallery Images ', 'frontline' ),
				'subtitle' => esc_html__( 'Upload images or add from media library.', 'frontline' )
			)
		)
	) );

	$metabox->add_section( 'cms_pf_audio', array(
		'title'  => esc_html__( 'Audio', 'frontline' ),
		'fields' => array(
			array(
				'id'          => 'post-audio-url',
				'type'        => 'text',
				'title'       => esc_html__( 'Audio URL', 'frontline' ),
				'description' => esc_html__( 'Audio file URL in format: mp3, ogg, wav.', 'frontline' ),
				'validate'    => 'url',
				'msg'         => 'Url error!'
			)
		)
	) );

	$metabox->add_section( 'cms_pf_link', array(
		'title'  => esc_html__( 'Link', 'frontline' ),
		'fields' => array(
			array(
				'id'       => 'post-link-url',
				'type'     => 'text',
				'title'    => esc_html__( 'URL', 'frontline' ),
				'validate' => 'url',
				'msg'      => 'Url error!'
			)
		)
	) );

	$metabox->add_section( 'cms_pf_quote', array(
		'title'  => esc_html__( 'Quote', 'frontline' ),
		'fields' => array(
			array(
				'id'    => 'post-quote-cite',
				'type'  => 'text',
				'title' => esc_html__( 'Cite', 'frontline' )
			)
		)
	) );
    /**
     * Config Case Study meta options
     *
     */
    $metabox->add_section( 'portfolio', array(
        'title'  => esc_html__( 'Content', 'frontline' ),
        'icon'   => 'el-icon-pencil',
        'fields' => array(
            array(
                'id'             => 'portfolio_content_padding',
                'type'           => 'spacing',
                'output'         => array( '.single-portfolio #content'),
                'right'          => false,
                'left'           => false,
                'mode'           => 'padding',
                'units'          => array( 'px' ),
                'units_extended' => 'false',
                'title'          => esc_html__( 'Content Padding', 'frontline' ),
                'desc'           => esc_html__( 'Default: Theme Option.', 'frontline' ),
                'default'        => array(
                    'padding-top'    => '',
                    'padding-bottom' => '',
                    'units'          => 'px',
                )
            ),
            array(
                'id'      => 'show_sidebar_portfolio',
                'type'    => 'switch',
                'title'   => esc_html__( 'Show Sidebar', 'frontline' ),
                'default' => true,
                'indent'  => true
            ),
        )
    ) );
    $metabox->add_section( 'portfolio', array(
        'title'  => esc_html__( 'Widget Information', 'frontline' ),
        'icon'   => 'el-icon-pencil',
        'fields' => array(
            array(
                'id'           => 'wg_client',
                'type'         => 'text',
                'title'        => esc_html__( 'Client', 'frontline' ),
                'force_output' => true
            ),
            array(
                'id'           => 'wg_date',
                'type'         => 'text',
                'title'        => esc_html__( 'Date', 'frontline' ),
                'force_output' => true
            ),
            array(
                'id'           => 'wg_website',
                'type'         => 'text',
                'title'        => esc_html__( 'Website', 'frontline' ),
                'force_output' => true
            ),
            array(
                'id'           => 'wg_category',
                'type'         => 'text',
                'title'        => esc_html__( 'Category', 'frontline' ),
                'force_output' => true
            ),
            array(
                'id'           => 'wg_awarded',
                'type'         => 'text',
                'title'        => esc_html__( 'Awarded', 'frontline' ),
                'force_output' => true
            ),
            array(
                'id'           => 'wg_awarded_desc',
                'type'         => 'text',
                'title'        => esc_html__( 'Awarded Description', 'frontline' ),
                'force_output' => true
            ),
            array(
                'id'=>'wg_download_1',
                'type' => 'textarea',
                'title' => esc_html__('Html Download Button 1', 'frontline'),
                'validate' => 'html_custom',
                'default' => '',
                'allowed_html' => array(
                    'a' => array(
                        'href' => array(),
                        'title' => array(),
                        'class' => array(),
                    ),
                    'i' => array(
                        'class' => array(),
                    ),
                    'span' => array(),
                    'p' => array(),
                    'div' => array(
                        'class' => array()
                    ),
                )
            ),
            array(
                'id'=>'wg_download_2',
                'type' => 'textarea',
                'title' => esc_html__('Html Download Button 2', 'frontline'),
                'validate' => 'html_custom',
                'default' => '',
                'allowed_html' => array(
                    'a' => array(
                        'href' => array(),
                        'title' => array(),
                        'class' => array(),
                    ),
                    'i' => array(
                        'class' => array(),
                    ),
                    'span' => array(),
                    'p' => array(),
                    'div' => array(
                        'class' => array()
                    ),
                )
            ),
            array(
                'id'=>'wg_download_3',
                'type' => 'textarea',
                'title' => esc_html__('Html Download Button 3', 'frontline'),
                'subtitle'           => esc_html__( 'Show in case studies grid. ', 'frontline' ),
                'validate' => 'html_custom',
                'default' => '',
                'allowed_html' => array(
                    'a' => array(
                        'href' => array(),
                        'title' => array(),
                        'class' => array(),
                    ),
                    'i' => array(
                        'class' => array(),
                    ),
                    'span' => array(),
                    'p' => array(),
                    'div' => array(
                        'class' => array()
                    ),
                )
            ),
        )
    ) );

    /**
     * Config Practice Area options
     *
     */
    $metabox->add_section( 'area', array(
        'title'  => esc_html__( 'Content', 'frontline' ),
        'icon'   => 'el-icon-pencil',
        'fields' => array(
            array(
                'id'             => 'area_content_padding',
                'type'           => 'spacing',
                'output'         => array( '.single-area #content'),
                'right'          => false,
                'left'           => false,
                'mode'           => 'padding',
                'units'          => array( 'px' ),
                'units_extended' => 'false',
                'title'          => esc_html__( 'Content Padding', 'frontline' ),
                'desc'           => esc_html__( 'Default: Theme Option.', 'frontline' ),
                'default'        => array(
                    'padding-top'    => '',
                    'padding-bottom' => '',
                    'units'          => 'px',
                )
            ),
            array(
                'id'      => 'show_sidebar_area',
                'type'    => 'switch',
                'title'   => esc_html__( 'Show Sidebar', 'frontline' ),
                'default' => true,
                'indent'  => true
            ),
        )
    ) );
    $metabox->add_section( 'area', array(
        'title'  => esc_html__( 'Additional Info', 'frontline' ),
        'icon'   => 'el-icon-pencil',
        'fields' => array(
            array(
                'id' => 'area_icon',
                'type' => 'media',
                'title' => esc_html__('Practice Area Icon Image', 'frontline'),
                'desc'           => esc_html__( 'Use svg image for nice styling', 'frontline' ),
            ),
            array(
                'id'=>'area_download_1',
                'type' => 'textarea',
                'title' => esc_html__('Html Download Button 1', 'frontline'),
                'validate' => 'html_custom',
                'default' => '',
                'allowed_html' => array(
                    'a' => array(
                        'href' => array(),
                        'title' => array(),
                        'class' => array(),
                    ),
                    'i' => array(
                        'class' => array(),
                    ),
                    'span' => array(),
                    'p' => array(),
                    'div' => array(
                        'class' => array()
                    ),
                )
            ),
            array(
                'id'=>'area_download_2',
                'type' => 'textarea',
                'title' => esc_html__('Html Download Button 2', 'frontline'),
                'validate' => 'html_custom',
                'default' => '',
                'allowed_html' => array(
                    'a' => array(
                        'href' => array(),
                        'title' => array(),
                        'class' => array(),
                    ),
                    'i' => array(
                        'class' => array(),
                    ),
                    'span' => array(),
                    'p' => array(),
                    'div' => array(
                        'class' => array()
                    ),
                )
            ),
        )
    ) );

    /**
     * Config Attorney meta options
     *
     */
    $metabox->add_section( 'attorney', array(
        'title'  => esc_html__( 'Content', 'frontline' ),
        'icon'   => 'el-icon-pencil',
        'fields' => array(
            array(
                'id'             => 'attorney_content_padding',
                'type'           => 'spacing',
                'output'         => array( '.single-attorney #content'),
                'right'          => false,
                'left'           => false,
                'mode'           => 'padding',
                'units'          => array( 'px' ),
                'units_extended' => 'false',
                'title'          => esc_html__( 'Content Padding', 'frontline' ),
                'desc'           => esc_html__( 'Default: Theme Option.', 'frontline' ),
                'default'        => array(
                    'padding-top'    => '',
                    'padding-bottom' => '',
                    'units'          => 'px',
                )
            ),
            array(
                'id'      => 'attorney_show_review',
                'type'    => 'switch',
                'title'   => esc_html__( 'Show Review', 'frontline' ),
                'subtitle' => esc_html__('Show review on single.', 'frontline'),
                'default' => true,
                'indent'  => true
            ),
            array(
                'id'      => 'attorney_show_contact',
                'type'    => 'switch',
                'title'   => esc_html__( 'Show Contact Form', 'frontline' ),
                'subtitle' => esc_html__('Show form contact to attorney on single.', 'frontline'),
                'default' => true,
                'indent'  => true
            ),
            array(
                'id' => 'attorney_contact_form',
                'type' => 'select',
                'title' => esc_html__('Select Contact Form', 'frontline'),
                'options' => $contact_forms,
                'default' => '',
                'required' => array(0 => 'attorney_show_contact', 1 => 'equals', 2 => true),
                'force_output' => true
            ),
        )
    ) );
    $metabox->add_section( 'attorney', array(
        'title'  => esc_html__( 'Page Title', 'frontline' ),
        'icon'   => 'el el-indent-left',
        'fields' => array(
            array(
                'id'           => 'custom_pagetitle',
                'type'         => 'button_set',
                'title'        => esc_html__( 'Page Title', 'frontline' ),
                'options'      => array(
                    'themeoption'  => esc_html__( 'Theme Option', 'frontline' ),
                    'show'  => esc_html__( 'Custom', 'frontline' ),
                    'hide'  => esc_html__( 'Hide', 'frontline' ),
                ),
                'default'      => 'themeoption',
            ),

            array(
                'id'       => 'ptitle_layout',
                'type'     => 'image_select',
                'title'    => esc_html__('Layout', 'frontline'),
                'subtitle' => esc_html__('Select a layout for page title.', 'frontline'),
                'options'  => array(
                    '' => get_template_directory_uri() . '/assets/images/ptitle-layout/p0.jpg',
                    '1' => get_template_directory_uri() . '/assets/images/ptitle-layout/p1.jpg',
                    '2' => get_template_directory_uri() . '/assets/images/ptitle-layout/p2.jpg',
                ),
                'default'  => '',
                'required'     => array( 0 => 'custom_pagetitle', 1 => '=', 2 => 'show' ),
                'force_output' => true
            ),

            array(
                'id'           => 'custom_title',
                'type'         => 'text',
                'title'        => esc_html__( 'Title', 'frontline' ),
                'subtitle'     => esc_html__( 'Use custom title for this page. The default title will be used on document title.', 'frontline' ),
                'required'     => array( 0 => 'custom_pagetitle', 1 => '=', 2 => 'show' ),
                'force_output' => true
            ),
            array(
                'id'           => 'sub_title',
                'type'         => 'text',
                'title'        => esc_html__( 'Sub Title', 'frontline' ),
                'required'     => array( 0 => 'custom_pagetitle', 1 => '=', 2 => 'show' ),
                'force_output' => true
            ),
            array(
                'id'       => 'ptitle_bg',
                'type'     => 'background',
                'background-color'     => false,
                'background-repeat'     => false,
                'background-size'     => false,
                'background-attachment'     => false,
                'background-position'     => false,
                'title'    => esc_html__('Background', 'frontline'),
                'subtitle' => esc_html__('Page title background image.', 'frontline'),
                'required'     => array( 0 => 'custom_pagetitle', 1 => '=', 2 => 'show' ),
                'force_output' => true
            ),
            array(
                'id'             => 'ptitle_padding',
                'type'           => 'spacing',
                'output'         => array('.site #pagetitle.page-title'),
                'right'   => false,
                'left'    => false,
                'mode'           => 'padding',
                'units'          => array('px'),
                'units_extended' => 'false',
                'title'          => esc_html__('Page Title Padding', 'frontline'),
                'desc'           => esc_html__('Default: Top 144px, Bottom 132px', 'frontline'),
                'default'            => array(
                    'padding-top'   => '',
                    'padding-bottom'   => '',
                    'units'          => 'px',
                ),
                'required'     => array( 0 => 'custom_pagetitle', 1 => '=', 2 => 'show' ),
                'force_output' => true
            ),
        )
    ) );
    $metabox->add_section( 'attorney', array(
        'title'  => esc_html__( 'Attorney Information', 'frontline' ),
        'icon'   => 'el el-info-circle',
        'fields' => array(
            array(
                'id'           => 'act_position',
                'type'         => 'text',
                'title'        => esc_html__( 'Position', 'frontline' ),
                'default' => ''
            ),
            array(
                'id'           => 'act_experience',
                'type'         => 'text',
                'title'        => esc_html__( 'Experience', 'frontline' ),
                'default' => ''
            ),
            array(
                'id'           => 'act_location',
                'type'         => 'text',
                'title'        => esc_html__( 'Location', 'frontline' ),
                'default' => ''
            ),
            array(
                'id' => 'act_email',
                'type' => 'text',
                'title' => esc_html__('Email', 'frontline'),
                'validate' => 'email',
                'default' => ''
            ),
            array(
                'id' => 'act_phone',
                'type' => 'text',
                'title' => esc_html__('Phone', 'frontline'),
                'default' => ''
            ),
            array(
                'id' => 'act_facebook',
                'type' => 'text',
                'title' => esc_html__('Facebook', 'frontline'),
                'default' => ''
            ),
            array(
                'id' => 'act_twitter',
                'type' => 'text',
                'title' => esc_html__('Twitter', 'frontline'),
                'default' => ''
            ),
            array(
                'id' => 'act_skype',
                'type' => 'text',
                'title' => esc_html__('Skype', 'frontline'),
                'default' => ''
            ),
            array(
                'id' => 'act_instagram',
                'type' => 'text',
                'title' => esc_html__('Instagram', 'frontline'),
                'default' => ''
            ),
            array(
                'id'=>'act_download',
                'type' => 'textarea',
                'title' => esc_html__('Html Download Button', 'frontline'),
                'validate' => 'html_custom',
                'default' => '',
                'allowed_html' => array(
                    'a' => array(
                        'href' => array(),
                        'title' => array(),
                        'class' => array(),
                        'target'=> array(),
                    ),
                    'i' => array(
                        'class' => array(),
                    ),
                    'span' => array(),
                    'p' => array(),
                    'div' => array(
                        'class' => array()
                    ),
                )
            ),
        )
    ) );
}

function frontline_get_option_of_theme_options( $key, $default = '' ) {
	if ( empty( $key ) ) {
		return '';
	}
	$options = get_option( frontline_get_opt_name(), array() );
	$value   = isset( $options[ $key ] ) ? $options[ $key ] : $default;

	return $value;
}