<?php
/**
 * Custom template tags for this theme.
 *
 * @package Frontline
 */

/**
 * Header layout
 **/
function frontline_page_loading()
{
    $page_loading = frontline_get_opt('show_page_loading', false);

    if ($page_loading) { ?>
        <div id="cms-loadding" class="cms-loader">
            <div class="loading-spinner">
                <div class="loading-dot1"></div>
                <div class="loading-dot2"></div>
            </div>
        </div>
    <?php }
}

/**
 * Header layout
 **/
function frontline_header_layout()
{
    $header_layout = frontline_get_opt('header_layout', '1');
    $custom_header = frontline_get_page_opt('custom_header', '0');
    $slide_nav_on = frontline_get_opt('slide_nav_on', false);

    if ($custom_header == '1' && !is_search()) {
        $page_header_layout = frontline_get_page_opt('header_layout');
        $header_layout = $page_header_layout;
        if ($header_layout == '0') {
            return;
        }
    }

    get_template_part('template-parts/header-layout', $header_layout);
    if ($header_layout == '1') {
        if ($slide_nav_on) {
            get_template_part('template-parts/slide-nav');
        }
    }
}

/**
 * Page title layout
 **/
function frontline_page_title_layout()
{
    get_template_part('template-parts/page-title', '');
}

/**
 * Page title layout
 **/
function frontline_footer()
{
    if (is_404()) {
        return true;
    }
    $footer_layout = frontline_get_opt('footer_layout', '1');
    $custom_footer = frontline_get_page_opt('custom_footer', '0');

    if (is_page() && $custom_footer == '1') {
        $page_footer_layout = frontline_get_page_opt('footer_layout');
        $footer_layout = $page_footer_layout;
    }
    if ($footer_layout == '0') {
        return;
    }
    get_template_part('template-parts/footer-layout', $footer_layout);
}

/**
 * Set primary content class based on sidebar position
 *
 * @param  string $sidebar_pos
 * @param  string $extra_class
 */
function frontline_primary_class($sidebar_pos, $extra_class = '')
{
    if (class_exists('WooCommerce') && (is_product_category()) || class_exists('WooCommerce') && (is_shop())) :
        $sidebar_load = 'sidebar-shop';
    elseif (is_single('portfolio')) :
        $sidebar_load = 'sidebar-portfolio';
    elseif (is_single('area')) :
        $sidebar_load = 'sidebar-area';
    else :
        $sidebar_load = 'sidebar-blog';
    endif;

    if (is_active_sidebar($sidebar_load)) {
        $class = array(trim($extra_class));
        switch ($sidebar_pos) {
            case 'left':
                $class[] = 'content-has-sidebar float-right col-xl-8 col-lg-8 col-md-12';
                break;

            case 'right':
                $class[] = 'content-has-sidebar float-left col-xl-8 col-lg-8 col-md-12';
                break;

            default:
                $class[] = 'content-full-width col-12';
                break;
        }

        $class = implode(' ', array_filter($class));

        if ($class) {
            echo ' class="' . esc_html($class) . '"';
        }
    } else {
        echo ' class="content-area col-12"';
    }
}

/**
 * Set secondary content class based on sidebar position
 *
 * @param  string $sidebar_pos
 * @param  string $extra_class
 */
function frontline_secondary_class($sidebar_pos, $extra_class = '')
{
    if (class_exists('WooCommerce') && (is_product_category())) :
        $sidebar_load = 'sidebar-shop';
    elseif (is_page()) :
        $sidebar_load = 'sidebar-page';
    elseif (is_post_type_archive('recipe') || is_tax('recipe-diet')) :
        $sidebar_load = 'sidebar-recipe';
    else :
        $sidebar_load = 'sidebar-blog';
    endif;

    if (is_active_sidebar($sidebar_load)) {
        $class = array(trim($extra_class));
        switch ($sidebar_pos) {
            case 'left':
                $class[] = 'widget-has-sidebar sidebar-fixed col-xl-4 col-lg-4 col-md-12';
                break;

            case 'right':
                $class[] = 'widget-has-sidebar sidebar-fixed col-xl-4 col-lg-4 col-md-12';
                break;

            default:
                break;
        }

        $class = implode(' ', array_filter($class));

        if ($class) {
            echo ' class="' . esc_html($class) . '"';
        }
    }
}


/**
 * Prints HTML for breadcrumbs.
 */
function frontline_breadcrumb()
{
    if (!class_exists('CMS_Breadcrumb')) {
        return;
    }

    $breadcrumb = new CMS_Breadcrumb();
    $entries = $breadcrumb->get_entries();

    if (empty($entries)) {
        return;
    }

    ob_start();

    foreach ($entries as $entry) {
        $entry = wp_parse_args($entry, array(
            'label' => '',
            'url' => ''
        ));

        if (empty($entry['label'])) {
            continue;
        }

        echo '<li>';

        if (!empty($entry['url'])) {
            printf(
                '<a class="breadcrumb-entry" href="%1$s">%2$s</a>',
                esc_url($entry['url']),
                esc_attr($entry['label'])
            );
        } else {
            printf('<span class="breadcrumb-entry" >%s</span>', esc_html($entry['label']));
        }

        echo '</li>';
    }

    $output = ob_get_clean();

    if ($output) {
        printf('<ul class="cms-breadcrumb">%s</ul>', wp_kses_post($output));
    }
}


function frontline_entry_link_pages()
{
    wp_link_pages(array(
        'before' => '<div class="page-links">',
        'after' => '</div>',
        'link_before' => '<span>',
        'link_after' => '</span>',
    ));
}


if (!function_exists('frontline_entry_excerpt')) :
    /**
     * Print post excerpt based on length.
     *
     * @param  integer $length
     */
    function frontline_entry_excerpt($length = 55)
    {
        $cms_the_excerpt = get_the_excerpt();
        if (!empty($cms_the_excerpt)) {
            echo esc_html($cms_the_excerpt);
        } else {
            echo wp_kses_post(frontline_get_the_excerpt($length));
        }
    }
endif;

/**
 * Prints post edit link when applicable
 */
function frontline_entry_edit_link()
{
    edit_post_link(
        sprintf(
            wp_kses(
            /* translators: %s: Name of current post. Only visible to screen readers */
                esc_html__('Edit', 'frontline'),
                array(
                    'span' => array(
                        'class' => array(),
                    ),
                )
            ),
            get_the_title()
        ),
        '<div class="entry-edit-link"><i class="fa fa-edit"></i>',
        '</div>'
    );
}

if (!function_exists('frontline_ajax_paginate_links')) {
    function frontline_ajax_paginate_links($link)
    {
        $parts = parse_url($link);
        parse_str($parts['query'], $query);
        if (isset($query['page']) && !empty($query['page'])) {
            return '#' . $query['page'];
        } else {
            return '#1';
        }
    }
}

add_action('wp_ajax_frontline_get_pagination_html', 'frontline_get_pagination_html');
add_action('wp_ajax_nopriv_frontline_get_pagination_html', 'frontline_get_pagination_html');
if (!function_exists('frontline_get_pagination_html')) {
    function frontline_get_pagination_html()
    {
        try {
            if (!isset($_POST['query_vars'])) {
                throw new Exception(esc_html__('Something went wrong while requesting. Please try again!', 'frontline'));
            }
            $query = new WP_Query($_POST['query_vars']);
            ob_start();
            frontline_posts_pagination($query, true);
            $html = ob_get_clean();
            wp_send_json(
                array(
                    'status' => true,
                    'message' => esc_html__('Load Successfully!', 'frontline'),
                    'data' => array(
                        'html' => $html,
                        'query_vars' => $_POST['query_vars'],
                        'post' => $query->have_posts()
                    ),
                )
            );
        } catch (Exception $e) {
            wp_send_json(array('status' => false, 'message' => $e->getMessage()));
        }
        die;
    }
}

/**
 * Prints posts pagination based on query
 *
 * @param  WP_Query $query Custom query, if left blank, this will use global query ( current query )
 * @return void
 */
function frontline_posts_pagination($query = null, $ajax = false)
{
    if ($ajax) {
        add_filter('paginate_links', 'frontline_ajax_paginate_links');
    }

    $classes = array();

    if (empty($query)) {
        $query = $GLOBALS['wp_query'];
    }

    if (empty($query->max_num_pages) || !is_numeric($query->max_num_pages) || $query->max_num_pages < 2) {
        return;
    }

    $paged = $query->get('paged', '');

    if (!$paged && is_front_page() && !is_home()) {
        $paged = $query->get('page', '');
    }

    $paged = $paged ? intval($paged) : 1;

    $pagenum_link = html_entity_decode(get_pagenum_link());
    $query_args = array();
    $url_parts = explode('?', $pagenum_link);

    if (isset($url_parts[1])) {
        wp_parse_str($url_parts[1], $query_args);
    }

    $pagenum_link = remove_query_arg(array_keys($query_args), $pagenum_link);
    $pagenum_link = trailingslashit($pagenum_link) . '%_%';

    $html_prev = '<i class="zmdi zmdi-long-arrow-left"></i>';
    $html_next = '<i class="zmdi zmdi-long-arrow-right"></i>';
    $paginate_links_args = array(
        'base' => $pagenum_link,
        'total' => $query->max_num_pages,
        'current' => $paged,
        'mid_size' => 1,
        'add_args' => array_map('urlencode', $query_args),
        'prev_text' => $html_prev,
        'next_text' => $html_next,
    );
    if ($ajax) {
        $paginate_links_args['format'] = '?page=%#%';
    }
    $links = paginate_links($paginate_links_args);
    if ($links):
        ?>
        <nav class="navigation posts-pagination <?php echo esc_attr($ajax ? 'ajax' : ''); ?>">
            <div class="posts-page-links">
                <?php
                printf($links);
                ?>
            </div>
        </nav>
    <?php
    endif;
}

/**
 * Prints archive meta on blog
 */
if (!function_exists('frontline_archive_meta')) :
    function frontline_archive_meta()
    {
        $archive_author_on = frontline_get_opt('archive_author_on', false);
        $archive_categories_on = frontline_get_opt('archive_categories_on', true);
        $archive_comments_on = frontline_get_opt('archive_comments_on', true);
        $archive_date_on = frontline_get_opt('archive_date_on', true);
        $archive_tags_on = frontline_get_opt('archive_tags_on', true);
        if ($archive_author_on || $archive_comments_on || $archive_categories_on || $archive_date_on || $archive_tags_on) : ?>
            <ul class="entry-meta">
                <?php if ($archive_author_on) : ?>
                    <li class="item-author">
                        <span><?php echo esc_html__('By', 'frontline'); ?></span>
                        <?php the_author_posts_link(); ?>
                    </li>
                <?php endif; ?>
                <?php if ($archive_date_on) : ?>
                    <li><?php echo get_the_date(); ?></li>
                <?php endif; ?>
                <?php if ($archive_categories_on) : ?>
                    <li class="item-category"><?php the_terms(get_the_ID(), 'category', '', ', '); ?></li>
                <?php endif; ?>
                <?php if($archive_tags_on && get_the_tags()){ ?>
                    <li>
                        <?php  the_tags('',', ',''); ?>
                    </li>
                <?php } ?>
                <?php if ($archive_comments_on) : ?>
                    <li class="item-comment"><a
                                href="<?php the_permalink(); ?>"><?php comments_number(esc_html__('No Comments', 'frontline'), esc_html__('Comments: 1', 'frontline'), esc_html__('Comments: %', 'frontline')); ?></a>
                    </li>
                <?php endif; ?>
            </ul>
        <?php endif;
    }
endif;

if (!function_exists('frontline_post_meta')) :
    function frontline_post_meta()
    {
        $post_author_on = frontline_get_opt('post_author_on', false);
        $post_categories_on = frontline_get_opt('post_categories_on', true);
        $post_comments_on = frontline_get_opt('post_comments_on', true);
        $post_date_on = frontline_get_opt('post_date_on', true);
        if ($post_author_on || $post_comments_on || $post_categories_on || $post_date_on) : ?>
            <ul class="entry-meta">
                <?php if ($post_author_on) : ?>
                    <li class="item-author">
                        <span><?php echo esc_html__('By', 'frontline'); ?></span>
                        <?php the_author_posts_link(); ?>
                    </li>
                <?php endif; ?>
                <?php if ($post_date_on) : ?>
                    <li><?php echo get_the_date(); ?></li>
                <?php endif; ?>
                <?php if ($post_categories_on) : ?>
                    <li class="item-category"><?php the_terms(get_the_ID(), 'category', '', ', '); ?></li>
                <?php endif; ?>
                <?php if ($post_comments_on) : ?>
                    <li class="item-comment"><a
                                href="<?php the_permalink(); ?>"><?php echo comments_number(esc_html__('No Comments', 'frontline'), esc_html__('Comment: 1', 'frontline'), esc_html__('Comments: %', 'frontline')); ?></a>
                    </li>
                <?php endif; ?>
            </ul>
        <?php endif;
    }
endif;

/**
 * Prints tag list
 */
if (!function_exists('frontline_entry_tagged_in')) :
    /**
     * Prints HTML with meta information for the current post-date/time.
     */
    function frontline_entry_tagged_in()
    {
        $tags_list = get_the_tag_list('', ' ');
        if ($tags_list) {
            echo '<div class="entry-content-bottom clearfix">';
            echo '<div class="entry-tags">';
            printf('%2$s', '', $tags_list);
            echo '</div>';
            echo '</div>';
        }
    }
endif;

/**
 * List socials share for post.
 */
function frontline_socials_share_default($post_id = 0)
{
    if ($post_id == 0) {
        ?>
        <ul>
            <li><a class="fb-social" title="Facebook" target="_blank"
                   href="https://www.facebook.com/sharer/sharer.php?u=<?php the_permalink(); ?>"><i
                            class="fa fa-facebook" aria-hidden="true"></i></a></li>
            <li><a class="tw-social" title="Twitter" target="_blank"
                   href="https://twitter.com/home?status=<?php the_permalink(); ?>"><i class="fa fa-twitter"
                                                                                       aria-hidden="true"></i></a></li>
            <li><a class="pin-social" title="Pinterest" target="_blank"
                   href="https://pinterest.com/pin/create/button/?url=<?php the_post_thumbnail_url('full'); ?>&media=&description=<?php echo urlencode(the_title_attribute('echo=0')); ?>"><i
                            class="fa fa-pinterest" aria-hidden="true"></i></a></li>
            <li><a class="g-social" title="Google Plus" target="_blank"
                   href="https://plus.google.com/share?url=<?php the_permalink(); ?>"><i class="fa fa-google-plus"
                                                                                         aria-hidden="true"></i></a>
            </li>
        </ul>
        <?php
    } else {
        $post = get_post($post_id);
        if ($post) {
            ?>
            <ul>
                <li><a class="fb-social" title="Facebook" target="_blank"
                       href="https://www.facebook.com/sharer/sharer.php?u=<?php echo esc_url(get_the_permalink($post_id)); ?>"><i
                                class="fa fa-facebook" aria-hidden="true"></i></a></li>
                <li><a class="tw-social" title="Twitter" target="_blank"
                       href="https://twitter.com/home?status=<?php echo esc_url(get_the_permalink($post_id)); ?>"><i
                                class="fa fa-twitter" aria-hidden="true"></i></a></li>
                <li><a class="pin-social" title="Pinterest" target="_blank"
                       href="https://pinterest.com/pin/create/button/?url=<?php echo esc_url(get_the_post_thumbnail_url($post_id, 'full')); ?>&media=&description=<?php echo urlencode(the_title_attribute(array('echo' => false, 'post' => $post))); ?>"><i
                                class="fa fa-pinterest" aria-hidden="true"></i></a></li>
                <li><a class="g-social" title="Google Plus" target="_blank"
                       href="https://plus.google.com/share?url=<?php echo esc_url(get_the_permalink($post_id)); ?>"><i
                                class="fa fa-google-plus" aria-hidden="true"></i></a></li>
            </ul>
            <?php
        }
    }
}

/**
 * Footer Top
 */
function frontline_footer_top()
{
    $footer_top_column = frontline_get_opt('footer_top_column');
    if (empty($footer_top_column))
        return;
    $_class = "";
    switch ($footer_top_column) {
        case '2':
            $_class = 'col-xl-6 col-lg-6 col-md-6 col-sm-12';
            break;
        case '3':
            $_class = 'col-xl-4 col-lg-4 col-md-4 col-sm-12';
            break;
        case '4':
            $_class = 'col-xl-3 col-lg-3 col-md-6 col-sm-12';
            break;
    }
    for ($i = 1; $i <= $footer_top_column; $i++) {
        if (is_active_sidebar('sidebar-footer-' . $i)) {
            echo '<div class="cms-footer-item ' . esc_html($_class) . '">';
            dynamic_sidebar('sidebar-footer-' . $i);
            echo "</div>";
        }
    }
}

/**
 * Search Popup
 */
function frontline_search_popup()
{
    $search_on = frontline_get_opt('search_on', false);
    if ($search_on) { ?>
        <div class="cms-modal cms-modal-search">
            <div class="cms-modal-close">x</div>
            <div class="cms-modal-content">
                <form role="search" method="get" class="search-form-popup"
                      action="<?php echo esc_url(home_url('/')); ?>">
                    <div class="searchform-wrap">
                        <input type="text" placeholder="<?php echo esc_attr__('Enter Keywords...', 'frontline'); ?>"
                               id="search" name="s" class="search-field"/>
                        <button type="submit" class="search-submit"><i class="fa fa-search"></i></button>
                    </div>
                </form>
            </div>
        </div>
    <?php }
}

/**
 * Sidebar Hidden
 */
function frontline_sidebar_hidden()
{
    $hidden_sidebar_on = frontline_get_opt('hidden_sidebar_on', false);
    if ($hidden_sidebar_on && is_active_sidebar('sidebar-hidden')) { ?>
        <div class="cms-hidden-sidebar">
            <div class="cms-hidden-close fa fa-close"></div>
            <div class="cms-hidden-sidebar-inner">
                <?php dynamic_sidebar('sidebar-hidden'); ?>
            </div>
        </div>
    <?php }
}

function frontline_social_share_product()
{ ?>
    <a class="fb-social hover-effect" title="Facebook" target="_blank"
       href="https://www.facebook.com/sharer/sharer.php?u=<?php the_permalink(); ?>"><i class="zmdi zmdi-facebook"></i></a>
    <a class="tw-social hover-effect" title="Twitter" target="_blank"
       href="https://twitter.com/home?status=<?php the_permalink(); ?>"><i class="zmdi zmdi-twitter"></i></a>
    <a class="g-social hover-effect" title="Google Plus" target="_blank"
       href="https://plus.google.com/share?url=<?php the_permalink(); ?>"><i class="zmdi zmdi-google-plus"></i></a>
    <a class="pin-social hover-effect" title="Pinterest" target="_blank"
       href="https://pinterest.com/pin/create/button/?url=<?php echo esc_url(the_post_thumbnail_url('full')); ?>&media=&description=<?php the_title(); ?>"><i
                class="zmdi zmdi-pinterest"></i></a>
    <?php
}

function frontline_product_nav()
{
    if ( is_singular('product') ) {
        global $post;
        // get categories
        $terms = wp_get_post_terms( $post->ID, 'product_cat' );
        foreach ( $terms as $term ) $cats_array[] = $term->term_id;
        // get all posts in current categories
        $query_args = array('posts_per_page' => -1, 'post_status' => 'publish', 'post_type' => 'product', 'tax_query' => array(
            array(
                'taxonomy' => 'product_cat',
                'field' => 'id',
                'terms' => $cats_array
            )));
        $r = new WP_Query($query_args);
        // show next and prev only if we have 3 or more
        if ($r->post_count > 2) {
            $prev_product_id = -1;
            $next_product_id = -1;
            $found_product = false;
            $i = 0;
            //Tony get current post from out of loop
            $current_product_index = $i;
            $current_product_id = get_the_ID();
            if ($r->have_posts()) {
                while ($r->have_posts()) {
                    $r->the_post();
                    $current_id = get_the_ID();
                    if ($current_id == $current_product_id) {
                        $found_product = true;
                        $current_product_index = $i;
                    }
                    //Keep find and change prev product until current product is found
                    if (!$found_product && $current_id != $current_product_id) {
                        $prev_product_id = get_the_ID();
                    }
                    //After current product is found
                    if ($found_product && $i == $current_product_index + 1) {
                        $next_product_id = get_the_ID();
                    }
                    $i++;
                }
                // Show button nav
                if ($prev_product_id != -1) {
                    ?>
                    <div class="product-nav prev-nav">
                        <a href="<?php echo esc_attr(get_the_permalink($prev_product_id)); ?>" title="<?php echo esc_attr(get_the_title($prev_product_id))?>">
                            <i class="zmdi zmdi-long-arrow-left"></i>
                            <ul class="font-smooth">
                                <li><?php echo esc_html__('Previous Product', 'frontline');?></li>
                                <li><?php echo esc_html(get_the_title($prev_product_id));?></li>
                            </ul>
                        </a>
                    </div>
                    <?php
                }
                if ($next_product_id != -1) {
                    ?>
                    <div class="product-nav next-nav">
                        <a href="<?php echo esc_attr(get_the_permalink($next_product_id)); ?>" title="<?php echo esc_attr(get_the_title($next_product_id))?>">
                            <i class="zmdi zmdi-long-arrow-right"></i>
                            <ul class="font-smooth">
                                <li><?php echo esc_html__('Next Product', 'frontline');?></li>
                                <li><?php echo esc_html(get_the_title($next_product_id));?></li>
                            </ul>
                        </a>
                    </div>
                    <?php
                }
            }
            wp_reset_postdata();
        }
    }
}

/**
 * Display navigation to next/previous post when applicable.
 */
function frontline_post_nav_default()
{
    global $post;
    // Don't print empty markup if there's nowhere to navigate.
    $previous = (is_attachment()) ? get_post($post->post_parent) : get_adjacent_post(false, '', true);
    $next = get_adjacent_post(false, '', false);

    if (!$next && !$previous)
        return;
    ?>
    <?php
    $next_post = get_next_post();
    $previous_post = get_previous_post();
    if (!empty($next_post) || !empty($previous_post)) { ?>
        <div class="post-previous-next default">
            <div class="nav-links row clearfix">
                <div class="nav-link-prev grid-item col-xl-6 col-lg-6 col-md-6 col-sm-12 col-12">
                    <?php if (is_a($previous_post, 'WP_Post') && get_the_title($previous_post->ID) != '') {
                        $url_prev = wp_get_attachment_image_src(get_post_thumbnail_id($previous_post->ID), 'thumbnail', false);
                        $image_alt = get_post_meta(get_post_thumbnail_id($previous_post->ID), '_wp_attachment_image_alt', true);
                        if (empty($image_alt)) {
                            $image_alt = get_the_title($previous_post->ID);
                        }
                        ?>
                        <div class="grid-item-inner">
                            <?php if (!empty($url_prev[0])) { ?>
                                <div class="item-featured">
                                    <a href="<?php echo esc_url(get_permalink($previous_post->ID)); ?>"
                                       class="image-link">
                                        <img src="<?php echo esc_url($url_prev[0]); ?>"
                                             alt="<?php echo esc_attr($image_alt); ?>"/>
                                        <div class="nav-arrow"><i class="zmdi zmdi-arrow-left"></i></div>
                                    </a>
                                </div>
                            <?php } ?>
                            <div class="item-holder">
                                <span><?php esc_html_e('Previous', 'frontline') ?></span>
                                <h4 class="item-title">
                                    <a href="<?php echo esc_url(get_permalink($previous_post->ID)); ?>"><?php echo get_the_title($previous_post->ID); ?></a>
                                </h4>
                            </div>
                        </div>
                    <?php } ?>
                </div>
                <div class="nav-link-next grid-item col-xl-6 col-lg-6 col-md-6 col-sm-12 col-12">
                    <?php if (is_a($next_post, 'WP_Post') && get_the_title($next_post->ID) != '') {
                        $url_next = wp_get_attachment_image_src(get_post_thumbnail_id($next_post->ID), 'thumbnail', false);
                        $image_alt = get_post_meta(get_post_thumbnail_id($next_post->ID), '_wp_attachment_image_alt', true);
                        if (empty($image_alt)) {
                            $image_alt = get_the_title($next_post->ID);
                        }
                        ?>
                        <div class="grid-item-inner">
                            <div class="item-holder">
                                <span><?php esc_html_e('Next', 'frontline') ?></span>
                                <h4 class="item-title">
                                    <a href="<?php echo esc_url(get_permalink($next_post->ID)); ?>"><?php echo get_the_title($next_post->ID); ?></a>
                                </h4>
                            </div>
                            <?php if (!empty($url_next[0])) { ?>
                                <div class="item-featured">
                                    <a href="<?php echo esc_url(get_permalink($next_post->ID)); ?>" class="image-link">
                                        <img src="<?php echo esc_url($url_next[0]); ?>"
                                             alt="<?php echo esc_attr($image_alt); ?>"/>
                                        <div class="nav-arrow"><i class="zmdi zmdi-arrow-right"></i></div>
                                    </a>
                                </div>
                            <?php } ?>
                        </div>
                    <?php } ?>
                </div>
            </div><!-- .nav-links -->
        </div>
    <?php }
}

/**
 * Social Media
 */
function frontline_social_media()
{
    $social_media = frontline_get_opt('social_media');
    $social = $social_media['enabled'];
    if ($social) : foreach ($social as $key => $value) { ?>
        <?php switch ($key) {

            case 'facebook':
                echo '<a title="Facebook" href="' . esc_url(frontline_get_opt('social_facebook_url')) . '"><i class="zmdi zmdi-facebook"></i></a>';
                break;

            case 'twitter':
                echo '<a title="Twitter" href="' . esc_url(frontline_get_opt('social_twitter_url')) . '"><i class="zmdi zmdi-twitter"></i></a>';
                break;

            case 'linkedin':
                echo '<a title="Linkedin" href="' . esc_url(frontline_get_opt('social_inkedin_url')) . '"><i class="zmdi zmdi-linkedin"></i></a>';
                break;

            case 'rss':
                echo '<a title="Rss" href="' . esc_url(frontline_get_opt('social_rss_url')) . '"><i class="zmdi zmdi-rss"></i></i></a>';
                break;

            case 'instagram':
                echo '<a title="Instagram" href="' . esc_url(frontline_get_opt('social_instagram_url')) . '"><i class="zmdi zmdi-instagram"></i></a>';
                break;

            case 'google':
                echo '<a title="Google+" href="' . esc_url(frontline_get_opt('social_google_url')) . '"><i class="zmdi zmdi-google-plus"></i></a>';
                break;

            case 'skype':
                echo '<a title="Skype" href="' . esc_url(frontline_get_opt('social_skype_url')) . '"><i class="zmdi zmdi-skype"></i></a>';
                break;

            case 'pinterest':
                echo '<a title="Pinterest" href="' . esc_url(frontline_get_opt('social_pinterest_url')) . '"><i class="zmdi zmdi-pinterest"></i></a>';
                break;

            case 'vimeo':
                echo '<a title="Vimeo" href="' . esc_url(frontline_get_opt('social_vimeo_url')) . '"><i class="zmdi zmdi-vimeo"></i></a>';
                break;

            case 'youtube':
                echo '<a title="Youtube" href="' . esc_url(frontline_get_opt('social_youtube_url')) . '"><i class="zmdi zmdi-youtube"></i></a>';
                break;

            case 'yelp':
                echo '<a title="Yelp" href="' . esc_url(frontline_get_opt('social_yelp_url')) . '"><i class="fa fa-yelp"></i></a>';
                break;

            case 'tumblr':
                echo '<a title="Tumblr" href="' . esc_url(frontline_get_opt('social_tumblr_url')) . '"><i class="fa fa-tumblr"></i></a>';
                break;

            case 'tripadvisor':
                echo '<a title="Tripadvisor" href="' . esc_url(frontline_get_opt('social_tripadvisor_url')) . '"><i class="fa fa-tripadvisor"></i></a>';
                break;

        }
    }
    endif;
}

/**
 * Get post grid template
 */
function get_post_list_layout1($posts = [], $settings = [])
{
    extract($settings);
    if ($thumbnail_size != 'custom') {
        $img_size = $thumbnail_size;
    } elseif (!empty($thumbnail_custom_dimension['width']) && !empty($thumbnail_custom_dimension['height'])) {
        $img_size = $thumbnail_custom_dimension['width'] . 'x' . $thumbnail_custom_dimension['height'];
    } else {
        $img_size = 'full';
    }
    if (is_array($posts)):
        foreach ($posts as $post):
            $img_id = get_post_thumbnail_id($post->ID);
            $img = etc_get_image_by_size(array(
                'attach_id' => $img_id,
                'thumb_size' => $img_size,
                'class' => '',
            ));
            $thumbnail = $img['thumbnail'];
            $item_class = "grid-item col-xl-{$col_xl} col-lg-{$col_lg} col-md-{$col_md} col-sm-{$col_sm} col-{$col_xs}";
            $author = get_user_by('id', $post->post_author);
            $comment_number = get_comments_number($post->ID);
            $comment_text = esc_html__('Comments', 'frontline');
            if ($comment_number == 1) {
                $comment_text = esc_html__('Comment', 'frontline');
            }
            ?>
            <div class="<?php echo esc_attr($item_class); ?>">
                <div class="grid-item-inner">
                    <?php if (has_post_thumbnail($post->ID) && wp_get_attachment_image_src(get_post_thumbnail_id($post->ID), false) && $show_thumbnail == 'true'): ?>
                        <div class="entry-featured">
                            <div class="post-image scale-hover">
                                <a href="<?php echo esc_url(get_permalink($post->ID)); ?>"><?php echo wp_kses_post($thumbnail); ?></a>
                            </div>
                        </div>
                    <?php endif; ?>
                    <div class="entry-body">
                        <div class="entry-body-inner">
                            <ul class="entry-meta font-smooth">
                                <li class="author">
                                    <a href="<?php echo esc_url(get_author_posts_url($post->post_author, $author->user_nicename)); ?>"><?php echo esc_html__('post by', 'frontline') . ' ' . esc_html($author->display_name); ?></a>
                                </li>
                                <li class="post-date">
                                    <?php $date_formart = get_option('date_format');
                                    echo get_the_date($date_formart, $post->ID); ?>
                                </li>
                                <li>
                                    <a href="<?php echo esc_url(get_permalink($post->ID)); ?>"><?php echo esc_html($comment_number) . ' ' . esc_html($comment_text); ?></a>
                                </li>
                            </ul>
                            <h2 class="item-title">
                                <a href="<?php echo esc_url(get_permalink($post->ID)); ?>"><?php echo esc_attr(get_the_title($post->ID)); ?></a>
                            </h2>
                            <div class="item-content">
                                <?php
                                if (!empty($post->post_excerpt)) {
                                    echo wp_trim_words($post->post_excerpt, $num_words, $more = null);
                                } else {
                                    $content = strip_shortcodes($post->post_content);
                                    $content = apply_filters('the_content', $content);
                                    $content = str_replace(']]>', ']]&gt;', $content);
                                    $content = wp_trim_words($content, $num_words, '&hellip;');
                                    echo wp_kses_post($content);
                                }
                                ?>
                            </div>
                            <div class="action-buttons">
                                <div class="item-readmore">
                                    <a class="btn btn-secondary"
                                       href="<?php echo esc_url(get_permalink($post->ID)); ?>"><?php echo esc_html($button_text); ?></a>
                                </div>
                                <?php if ($social_share) {
                                    ?>
                                    <div class="entry-social">
                                        <span class="label"><?php echo esc_html__('Share', 'frontline') . ': '; ?></span>
                                        <?php frontline_socials_share_default($post->ID); ?>
                                    </div>
                                    <?php
                                } ?>
                            </div>
                        </div>
                    </div>
                </div>
            </div>
        <?php
        endforeach;
    endif;
}

function get_case_studies_grid_layout1($posts = [], $settings = [])
{
    extract($settings);
    if ($thumbnail_size != 'custom') {
        $img_size = $thumbnail_size;
    } elseif (!empty($thumbnail_custom_dimension['width']) && !empty($thumbnail_custom_dimension['height'])) {
        $img_size = $thumbnail_custom_dimension['width'] . 'x' . $thumbnail_custom_dimension['height'];
    } else {
        $img_size = 'full';
    }
    if (is_array($posts)):
        foreach ($posts as $post):
            $img_id = get_post_thumbnail_id($post->ID);
            $img = etc_get_image_by_size(array(
                'attach_id' => $img_id,
                'thumb_size' => $img_size,
                'class' => '',
            ));
            $thumbnail = $img['thumbnail'];
            $item_class = "grid-item col-xl-{$col_xl} col-lg-{$col_lg} col-md-{$col_md} col-sm-{$col_sm} col-{$col_xs}";
            $filter_class = etc_get_term_of_post_to_class($post->ID, array_unique($tax));
            $wg_download_3 = get_post_meta($post->ID, 'wg_download_3', true);
            ?>
            <div class="<?php echo esc_attr($item_class . ' ' . $filter_class); ?>">
                <div class="grid-item-inner">
                    <?php if (has_post_thumbnail($post->ID) && wp_get_attachment_image_src(get_post_thumbnail_id($post->ID), false) && $show_thumbnail == 'true'): ?>
                        <div class="entry-featured">
                            <div class="post-image scale-hover">
                                <a href="<?php echo esc_url(get_permalink($post->ID)); ?>"><?php echo wp_kses_post($thumbnail); ?></a>
                            </div>
                        </div>
                    <?php endif; ?>

                    <div class="entry-body">
                        <?php if ($show_categories == 'true'): ?>
                            <div class="post-meta">
                                <?php the_terms($post->ID, 'portfolio-category', '', ', '); ?>
                            </div>
                        <?php endif; ?>

                        <?php if ($show_title == 'true'): ?>
                        <<?php etc_print_html($title_tag); ?> class="entry-title"><a
                                href="<?php echo esc_url(get_permalink($post->ID)); ?>"><?php echo esc_attr(get_the_title($post->ID)); ?></a>
                    </<?php etc_print_html($title_tag); ?>>
                <?php endif; ?>

                    <?php if ($show_excerpt == 'true'): ?>
                        <div class="entry-content">
                            <?php
                            if (!empty($post->post_excerpt)) {
                                echo wp_trim_words($post->post_excerpt, $num_words, $more = null);
                            } else {
                                $content = strip_shortcodes($post->post_content);
                                $content = apply_filters('the_content', $content);
                                $content = str_replace(']]>', ']]&gt;', $content);
                                $content = wp_trim_words($content, $num_words, '&hellip;');
                                echo wp_kses_post($content);
                            }
                            ?>
                        </div>
                    <?php endif; ?>
                    <div class="action-buttons">
                        <?php if ($show_button == 'true'): ?>
                            <div class="entry-readmore">
                                <a class="btn"
                                   href="<?php echo esc_url(get_permalink($post->ID)); ?>"><?php echo esc_html($button_text); ?></a>
                            </div>
                        <?php endif; ?>

                        <?php if ($show_button_download == 'true'): ?>
                            <?php if (!empty($wg_download_3)) : ?>
                                <div class="download-button btn btn-secondary"><?php echo wp_kses_post($wg_download_3); ?></div>
                            <?php endif; ?>
                        <?php endif; ?>
                    </div>
                </div>
            </div>
            </div>
        <?php
        endforeach;
    endif;
}

function get_case_studies_grid_layout2($posts = [], $settings = [])
{
    extract($settings);
    if ($thumbnail_size != 'custom') {
        $img_size = $thumbnail_size;
    } elseif (!empty($thumbnail_custom_dimension['width']) && !empty($thumbnail_custom_dimension['height'])) {
        $img_size = $thumbnail_custom_dimension['width'] . 'x' . $thumbnail_custom_dimension['height'];
    } else {
        $img_size = 'full';
    }
    if (is_array($posts)):
        foreach ($posts as $post):
            $img_id = get_post_thumbnail_id($post->ID);
            $img = etc_get_image_by_size(array(
                'attach_id' => $img_id,
                'thumb_size' => $img_size,
                'class' => '',
            ));
            $thumbnail = $img['thumbnail'];
            $item_class = "grid-item col-xl-{$col_xl} col-lg-{$col_lg} col-md-{$col_md} col-sm-{$col_sm} col-{$col_xs}";
            $filter_class = etc_get_term_of_post_to_class($post->ID, array_unique($tax));
            ?>
            <div class="<?php echo esc_attr($item_class . ' ' . $filter_class); ?>">
                <div class="grid-item-inner">
                    <?php if (has_post_thumbnail($post->ID) && wp_get_attachment_image_src(get_post_thumbnail_id($post->ID), false) && $show_thumbnail == 'true'): ?>
                        <div class="entry-featured">
                            <div class="post-image">
                                <?php echo wp_kses_post($thumbnail); ?>
                            </div>
                        </div>
                    <?php endif; ?>

                    <div class="entry-body">
                        <div class="entry-body-inner">
                            <?php if ($show_categories == 'true'): ?>
                                <div class="post-meta">
                                    <?php the_terms($post->ID, 'portfolio-category', '', ', '); ?>
                                </div>
                            <?php endif; ?>

                            <?php if ($show_title == 'true'): ?>
                                <<?php etc_print_html($title_tag); ?> class="entry-title">
                                <a href="<?php echo esc_url(get_permalink($post->ID)); ?>"><?php echo esc_attr(get_the_title($post->ID)); ?></a>
                            </<?php etc_print_html($title_tag); ?>>
                            <?php endif; ?>

                            <?php if ($show_excerpt == 'true'): ?>
                                <div class="entry-content">
                                    <?php
                                    if (!empty($post->post_excerpt)) {
                                        echo wp_trim_words($post->post_excerpt, $num_words, $more = null);
                                    } else {
                                        $content = strip_shortcodes($post->post_content);
                                        $content = apply_filters('the_content', $content);
                                        $content = str_replace(']]>', ']]&gt;', $content);
                                        $content = wp_trim_words($content, $num_words, '&hellip;');
                                        echo wp_kses_post($content);
                                    }
                                    ?>
                                </div>
                            <?php endif; ?>
                            <div class="action-buttons">
                                <?php if ($show_button == 'true'): ?>
                                    <div class="entry-readmore">
                                        <a class="readmore-link" href="<?php echo esc_url(get_permalink($post->ID)); ?>"><?php echo esc_html($button_text); ?> <i class="fa fa-long-arrow-right"></i></a>
                                    </div>
                                <?php endif; ?>
                            </div>
                        </div>
                    </div>
                </div>
            </div>
        <?php
        endforeach;
    endif;
}

function get_attorney_grid_layout1($posts = [], $settings = [])
{
    extract($settings);
    if ($thumbnail_size != 'custom') {
        $img_size = $thumbnail_size;
    } elseif (!empty($thumbnail_custom_dimension['width']) && !empty($thumbnail_custom_dimension['height'])) {
        $img_size = $thumbnail_custom_dimension['width'] . 'x' . $thumbnail_custom_dimension['height'];
    } else {
        $img_size = 'full';
    }
    if (is_array($posts)):
        foreach ($posts as $post):
            $img_id = get_post_thumbnail_id($post->ID);
            $img = etc_get_image_by_size(array(
                'attach_id' => $img_id,
                'thumb_size' => $img_size,
                'class' => '',
            ));
            $thumbnail = $img['thumbnail'];
            $item_class = "grid-item col-xl-{$col_xl} col-lg-{$col_lg} col-md-{$col_md} col-sm-{$col_sm} col-{$col_xs}";
            $act_position = get_post_meta($post->ID, 'act_position', true);
            $act_email = get_post_meta($post->ID, 'act_email', true);
            $act_phone = get_post_meta($post->ID, 'act_phone', true);
            $act_facebook = get_post_meta($post->ID, 'act_facebook', true);
            $act_twitter = get_post_meta($post->ID, 'act_twitter', true);
            $act_skype = get_post_meta($post->ID, 'act_skype', true);
            $act_instagram = get_post_meta($post->ID, 'act_instagram', true);
            ?>
            <div class="<?php echo esc_attr($item_class); ?>">
                <div class="grid-item-inner">
                    <?php if (has_post_thumbnail($post->ID) && wp_get_attachment_image_src(get_post_thumbnail_id($post->ID), false) && $show_thumbnail == 'true'): ?>
                        <div class="entry-featured">
                            <div class="post-image scale-hover">
                                <a href="<?php echo esc_url(get_permalink($post->ID)); ?>"><?php echo wp_kses_post($thumbnail); ?></a>
                            </div>
                        </div>
                    <?php endif; ?>

                    <div class="entry-body">
                        <?php if ($show_title == 'true'): ?>
                            <<?php etc_print_html($title_tag); ?> class="entry-title">
                                <a href="<?php echo esc_url(get_permalink($post->ID)); ?>"><?php echo esc_attr(get_the_title($post->ID)); ?></a>
                                <span class="position font-smooth"><?php echo esc_html('- '.$act_position); ?></span>
                            </<?php etc_print_html($title_tag); ?>>
                        <?php endif; ?>

                        <?php if ($show_excerpt == 'true'): ?>
                            <div class="entry-content">
                                <?php
                                if (!empty($post->post_excerpt)) {
                                    echo wp_trim_words($post->post_excerpt, $num_words, $more = null);
                                } else {
                                    $content = strip_shortcodes($post->post_content);
                                    $content = apply_filters('the_content', $content);
                                    $content = str_replace(']]>', ']]&gt;', $content);
                                    $content = wp_trim_words($content, $num_words, '&hellip;');
                                    echo wp_kses_post($content);
                                }
                                ?>
                            </div>
                        <?php endif; ?>

                        <?php if ($show_contact_info == 'true'): ?>
                            <div class="contact-info">
                                <?php
                                if (!empty($act_phone)){
                                    ?>
                                    <div class="contact-phone">
                                        <i class="zmdi zmdi-phone"></i>
                                        <span class="value"><?php echo esc_html($act_phone);?></span>
                                    </div>
                                    <?php
                                }
                                ?>
                                <?php
                                if (!empty($act_facebook) || !empty($act_twitter) || !empty($act_skype) || !empty($act_email || $act_instagram)){
                                    ?>
                                    <div class="contact-social">
                                        <ul class="info-social">
                                            <?php if(!empty($act_facebook)) : ?>
                                                <li><a href="<?php echo esc_url($act_facebook); ?>"><i class="zmdi zmdi-facebook"></i></a></li>
                                            <?php endif; ?>
                                            <?php if(!empty($act_twitter)) : ?>
                                                <li><a href="<?php echo esc_url($act_twitter); ?>"><i class="zmdi zmdi-twitter"></i></a></li>
                                            <?php endif; ?>
                                            <?php if(!empty($act_skype)) : ?>
                                                <li><a href="<?php echo esc_attr($act_skype); ?>"><i class="zmdi zmdi-skype"></i></a></li>
                                            <?php endif; ?>
                                            <?php if(!empty($act_instagram)) : ?>
                                                <li><a href="<?php echo esc_attr($act_instagram); ?>"><i class="zmdi zmdi-instagram"></i></a></li>
                                            <?php endif; ?>
                                            <?php if(!empty($act_email)) : ?>
                                                <li><a href="mailto:<?php echo str_replace(' ','',$act_email); ?>"><i class="zmdi zmdi-email-open"></i></a></li>
                                            <?php endif; ?>
                                        </ul>
                                    </div>
                                    <?php
                                }
                                ?>
                            </div>
                    <?php endif; ?>
                    </div>
                </div>
            </div>
        <?php
        endforeach;
    endif;
}

function get_attorney_grid_layout2($posts = [], $settings = [])
{
    extract($settings);
    if ($thumbnail_size != 'custom') {
        $img_size = $thumbnail_size;
    } elseif (!empty($thumbnail_custom_dimension['width']) && !empty($thumbnail_custom_dimension['height'])) {
        $img_size = $thumbnail_custom_dimension['width'] . 'x' . $thumbnail_custom_dimension['height'];
    } else {
        $img_size = 'full';
    }
    if (is_array($posts)):
        foreach ($posts as $post):
            $img_id = get_post_thumbnail_id($post->ID);
            $img = etc_get_image_by_size(array(
                'attach_id' => $img_id,
                'thumb_size' => $img_size,
                'class' => '',
            ));
            $thumbnail = $img['thumbnail'];
            $item_class = "grid-item col-xl-{$col_xl} col-lg-{$col_lg} col-md-{$col_md} col-sm-{$col_sm} col-{$col_xs}";
            $act_position = get_post_meta($post->ID, 'act_position', true);
            $act_email = get_post_meta($post->ID, 'act_email', true);
            $act_facebook = get_post_meta($post->ID, 'act_facebook', true);
            $act_twitter = get_post_meta($post->ID, 'act_twitter', true);
            $act_skype = get_post_meta($post->ID, 'act_skype', true);
            $act_instagram = get_post_meta($post->ID, 'act_instagram', true);
            ?>
            <div class="<?php echo esc_attr($item_class); ?>">
                <div class="grid-item-inner">
                    <?php if (has_post_thumbnail($post->ID) && wp_get_attachment_image_src(get_post_thumbnail_id($post->ID), false) && $show_thumbnail == 'true'): ?>
                        <div class="entry-featured">
                            <div class="post-image">
                                <a href="<?php echo esc_url(get_permalink($post->ID)); ?>"><?php echo wp_kses_post($thumbnail); ?></a>
                            </div>
                            <?php if ($show_contact_info == 'true'): ?>
                                <div class="contact-social">
                                    <ul class="info-social">
                                        <?php if(!empty($act_facebook)) : ?>
                                            <li><a href="<?php echo esc_url($act_facebook); ?>"><i class="zmdi zmdi-facebook"></i></a></li>
                                        <?php endif; ?>
                                        <?php if(!empty($act_twitter)) : ?>
                                            <li><a href="<?php echo esc_url($act_twitter); ?>"><i class="zmdi zmdi-twitter"></i></a></li>
                                        <?php endif; ?>
                                        <?php if(!empty($act_skype)) : ?>
                                            <li><a href="<?php echo esc_attr($act_skype); ?>"><i class="zmdi zmdi-skype"></i></a></li>
                                        <?php endif; ?>
                                        <?php if(!empty($act_instagram)) : ?>
                                            <li><a href="<?php echo esc_attr($act_instagram); ?>"><i class="zmdi zmdi-instagram"></i></a></li>
                                        <?php endif; ?>
                                        <?php if(!empty($act_email)) : ?>
                                            <li><a href="mailto:<?php echo str_replace(' ','',$act_email); ?>"><i class="zmdi zmdi-email-open"></i></a></li>
                                        <?php endif; ?>
                                    </ul>
                                </div>
                            <?php endif; ?>
                        </div>
                    <?php endif; ?>

                    <div class="entry-body">
                        <?php if ($show_title == 'true'): ?>
                            <<?php etc_print_html($title_tag); ?> class="entry-title">
                            <a href="<?php echo esc_url(get_permalink($post->ID)); ?>"><?php echo esc_attr(get_the_title($post->ID)); ?></a>
                            </<?php etc_print_html($title_tag); ?>>
                            <p class="position"><?php echo esc_html($act_position); ?></p>
                        <?php endif; ?>

                        <?php if ($show_excerpt == 'true'): ?>
                            <div class="entry-content">
                                <?php
                                if (!empty($post->post_excerpt)) {
                                    echo wp_trim_words($post->post_excerpt, $num_words, $more = null);
                                } else {
                                    $content = strip_shortcodes($post->post_content);
                                    $content = apply_filters('the_content', $content);
                                    $content = str_replace(']]>', ']]&gt;', $content);
                                    $content = wp_trim_words($content, $num_words, '&hellip;');
                                    echo wp_kses_post($content);
                                }
                                ?>
                            </div>
                        <?php endif; ?>
                    </div>
                </div>
            </div>
        <?php
        endforeach;
    endif;
}

function get_practice_area_grid_layout1($posts = [], $settings = [])
{
    extract($settings);
    if ($thumbnail_size != 'custom') {
        $img_size = $thumbnail_size;
    } elseif (!empty($thumbnail_custom_dimension['width']) && !empty($thumbnail_custom_dimension['height'])) {
        $img_size = $thumbnail_custom_dimension['width'] . 'x' . $thumbnail_custom_dimension['height'];
    } else {
        $img_size = 'full';
    }
    if (is_array($posts)):
        foreach ($posts as $post):
            $img_id = get_post_thumbnail_id($post->ID);
            $img = etc_get_image_by_size(array(
                'attach_id' => $img_id,
                'thumb_size' => $img_size,
                'class' => '',
            ));
            $thumbnail = $img['thumbnail'];
            $item_class = "grid-item col-xl-{$col_xl} col-lg-{$col_lg} col-md-{$col_md} col-sm-{$col_sm} col-{$col_xs}";
            ?>
            <div class="<?php echo esc_attr($item_class); ?>">
                <div class="grid-item-inner">
                    <?php if (has_post_thumbnail($post->ID) && wp_get_attachment_image_src(get_post_thumbnail_id($post->ID), false) && $show_thumbnail == 'true'): ?>
                        <div class="entry-featured">
                            <div class="post-image scale-hover">
                                <?php echo wp_kses_post($thumbnail); ?>
                            </div>
                        </div>
                    <?php endif; ?>
                    <div class="entry-body">
                        <div class="entry-body-inner">
                            <?php if ($show_title == 'true'): ?>
                            <<?php etc_print_html($title_tag); ?> class="entry-title">
                                <a href="<?php echo esc_url(get_permalink($post->ID)); ?>"><?php echo esc_attr(get_the_title($post->ID)); ?></a>
                            </<?php etc_print_html($title_tag); ?>>
                            <?php endif; ?>

                            <?php if ($show_excerpt == 'true'): ?>
                            <div class="entry-content">
                                <?php
                                if (!empty($post->post_excerpt)) {
                                    echo wp_trim_words($post->post_excerpt, $num_words, $more = null);
                                } else {
                                    $content = strip_shortcodes($post->post_content);
                                    $content = apply_filters('the_content', $content);
                                    $content = str_replace(']]>', ']]&gt;', $content);
                                    $content = wp_trim_words($content, $num_words, '&hellip;');
                                    echo wp_kses_post($content);
                                }
                                ?>
                            </div>
                            <?php endif; ?>
                            <div class="action-buttons">
                                <?php if ($show_button == 'true'): ?>
                                    <div class="entry-readmore">
                                        <a class="readmore-link" href="<?php echo esc_url(get_permalink($post->ID)); ?>"><?php echo esc_html($button_text); ?> <i class="fa fa-long-arrow-right"></i></a>
                                    </div>
                                <?php endif; ?>
                            </div>
                        </div>
                    </div>
                </div>
            </div>
        <?php
        endforeach;
    endif;
}

function get_practice_area_grid_layout2($posts = [], $settings = [])
{
    extract($settings);
    if (is_array($posts)):
        foreach ($posts as $post):
            $item_class = "grid-item col-xl-{$col_xl} col-lg-{$col_lg} col-md-{$col_md} col-sm-{$col_sm} col-{$col_xs}";
            $icon_image = get_post_meta($post->ID, 'area_icon',true);
            ?>
            <div class="<?php echo esc_attr($item_class); ?>">
                <div class="grid-item-inner">
                    <?php
                    if (!empty($icon_image['url']) && $show_icon == 'true' ){
                        ?>
                        <div class="area-icon-wrap">
                            <img class="svg area-icon" src="<?php echo esc_url($icon_image['url']); ?>" alt="<?php echo esc_attr($icon_image['alt']); ?>">
                        </div>
                        <?php
                    }
                    ?>
                    <div class="entry-body">
                        <div class="entry-body-inner">
                            <?php if ($show_title == 'true'): ?>
                            <<?php etc_print_html($title_tag); ?> class="entry-title">
                            <a href="<?php echo esc_url(get_permalink($post->ID)); ?>"><?php echo esc_attr(get_the_title($post->ID)); ?></a>
                        </<?php etc_print_html($title_tag); ?>>
                        <?php endif; ?>

                        <?php if ($show_excerpt == 'true'): ?>
                            <div class="entry-content">
                                <?php
                                if (!empty($post->post_excerpt)) {
                                    echo wp_trim_words($post->post_excerpt, $num_words, $more = null);
                                } else {
                                    $content = strip_shortcodes($post->post_content);
                                    $content = apply_filters('the_content', $content);
                                    $content = str_replace(']]>', ']]&gt;', $content);
                                    $content = wp_trim_words($content, $num_words, '&hellip;');
                                    echo wp_kses_post($content);
                                }
                                ?>
                            </div>
                        <?php endif; ?>
                        <div class="action-buttons">
                            <?php if ($show_button == 'true'): ?>
                                <div class="entry-readmore">
                                    <a class="readmore-link" href="<?php echo esc_url(get_permalink($post->ID)); ?>"><?php echo esc_html($button_text); ?> <i class="fa fa-long-arrow-right"></i></a>
                                </div>
                            <?php endif; ?>
                        </div>
                    </div>
                </div>
            </div>
            </div>
        <?php
        endforeach;
    endif;
}

function get_practice_area_grid_layout3($posts = [], $settings = [])
{
    extract($settings);
    if (is_array($posts)):
        foreach ($posts as $post):
            $item_class = "grid-item col-xl-{$col_xl} col-lg-{$col_lg} col-md-{$col_md} col-sm-{$col_sm} col-{$col_xs}";
            $icon_image = get_post_meta($post->ID, 'area_icon',true);
            ?>
            <div class="<?php echo esc_attr($item_class); ?>">
                <div class="grid-item-inner">
                    <?php
                    if (!empty($icon_image['url']) && $show_icon == 'true' ){
                        ?>
                        <div class="area-icon-wrap">
                            <img class="svg area-icon" src="<?php echo esc_url($icon_image['url']); ?>" alt="<?php echo esc_attr($icon_image['alt']); ?>">
                        </div>
                        <?php
                    }
                    ?>
                    <div class="entry-body">
                        <div class="entry-body-inner">
                            <?php if ($show_title == 'true'): ?>
                            <<?php etc_print_html($title_tag); ?> class="entry-title font-smooth">
                            <a href="<?php echo esc_url(get_permalink($post->ID)); ?>"><?php echo esc_attr(get_the_title($post->ID)); ?></a>
                        </<?php etc_print_html($title_tag); ?>>
                        <?php endif; ?>

                        <?php if ($show_excerpt == 'true'): ?>
                            <div class="entry-content">
                                <?php
                                if (!empty($post->post_excerpt)) {
                                    echo wp_trim_words($post->post_excerpt, $num_words, $more = null);
                                } else {
                                    $content = strip_shortcodes($post->post_content);
                                    $content = apply_filters('the_content', $content);
                                    $content = str_replace(']]>', ']]&gt;', $content);
                                    $content = wp_trim_words($content, $num_words, '&hellip;');
                                    echo wp_kses_post($content);
                                }
                                ?>
                            </div>
                        <?php endif; ?>
                        <div class="action-buttons">
                            <?php if ($show_button == 'true'): ?>
                                <div class="entry-readmore">
                                    <a class="readmore-link" href="<?php echo esc_url(get_permalink($post->ID)); ?>"><?php echo esc_html($button_text); ?> <i class="fa fa-long-arrow-right"></i></a>
                                </div>
                            <?php endif; ?>
                        </div>
                    </div>
                </div>
            </div>
            </div>
        <?php
        endforeach;
    endif;
}

if (!function_exists('frontline_get_post_grid')) {
    function frontline_get_post_grid($posts = [], $settings = [])
    {
        if (empty($posts) || !is_array($posts) || empty($settings) || !is_array($settings)) {
            return false;
        }
        switch ($settings['template_type']) {
            case 'post_list_layout1':
                get_post_list_layout1($posts, $settings);
                break;
            case 'case_studies_grid_layout1':
                get_case_studies_grid_layout1($posts, $settings);
                break;
            case 'case_studies_grid_layout2':
                get_case_studies_grid_layout2($posts, $settings);
                break;
            case 'attorney_grid_layout1':
                get_attorney_grid_layout1($posts, $settings);
                break;
            case 'attorney_grid_layout2':
                get_attorney_grid_layout2($posts, $settings);
                break;
            case 'practice_area_grid_layout1':
                get_practice_area_grid_layout1($posts, $settings);
                break;
            case 'practice_area_grid_layout2':
                get_practice_area_grid_layout2($posts, $settings);
                break;
            case 'practice_area_grid_layout3':
                get_practice_area_grid_layout3($posts, $settings);
                break;
            default:
                return false;
                break;
        }
    }
}


add_action('wp_ajax_frontline_load_more_post_grid', 'frontline_load_more_post_grid');
add_action('wp_ajax_nopriv_frontline_load_more_post_grid', 'frontline_load_more_post_grid');
if (!function_exists('frontline_load_more_post_grid')) {
    function frontline_load_more_post_grid()
    {
        try {
            if (!isset($_POST['settings'])) {
                throw new Exception(__('Something went wrong while requesting. Please try again!', 'frontline'));
            }
            $settings = $_POST['settings'];
            set_query_var('paged', $settings['paged']);
            extract(etc_get_posts_of_grid('post', [
                'source' => isset($settings['source']) ? $settings['source'] : '',
                'orderby' => isset($settings['orderby']) ? $settings['orderby'] : 'date',
                'order' => isset($settings['order']) ? $settings['order'] : 'desc',
                'limit' => isset($settings['limit']) ? $settings['limit'] : '6',
                'post_ids' => '',
            ]));
            ob_start();
            frontline_get_post_grid($posts, $settings);
            $html = ob_get_clean();
            wp_send_json(
                array(
                    'status' => true,
                    'message' => esc_html__('Load Successfully!', 'frontline'),
                    'data' => array(
                        'html' => $html,
                        'paged' => $settings['paged'],
                        'posts' => $posts,
                    ),
                )
            );
        } catch (Exception $e) {
            wp_send_json(array('status' => false, 'message' => $e->getMessage()));
        }
        die;
    }
}