<?php
if (!class_exists('ReduxFramework')) {
    return;
}
if (class_exists('ReduxFrameworkPlugin')) {
    remove_action('admin_notices', array(ReduxFrameworkPlugin::instance(), 'admin_notices'));
}

if(class_exists('Newsletter')) {
    $forms = array_filter( (array) get_option( 'newsletter_forms', array() ) );

    $newsletter_forms = array(
        'default' => esc_html__( 'Default Form', 'frontline' )
    );

    if ( $forms )
    {
        $index = 1;
        foreach ( $forms as $key => $form )
        {
            $newsletter_forms[ $key ] = sprintf( esc_html__( 'Form %s', 'frontline' ), $index );
            $index ++;
        }
    }
} else {
    $newsletter_forms = '';
}

$opt_name = frontline_get_opt_name();
$theme = wp_get_theme();

$args = array(
    // TYPICAL -> Change these values as you need/desire
    'opt_name'             => $opt_name,
    // This is where your data is stored in the database and also becomes your global variable name.
    'display_name'         => $theme->get('Name'),
    // Name that appears at the top of your panel
    'display_version'      => $theme->get('Version'),
    // Version that appears at the top of your panel
    'menu_type'            => class_exists('Elementor_Theme_Core') ? 'submenu' : '',
    //Specify if the admin menu should appear or not. Options: menu or submenu (Under appearance only)
    'allow_sub_menu'       => true,
    // Show the sections below the admin menu item or not
    'menu_title'           => esc_html__('Theme Options', 'frontline'),
    'page_title'           => esc_html__('Theme Options', 'frontline'),
    // You will need to generate a Google API key to use this feature.
    // Please visit: https://developers.google.com/fonts/docs/developer_api#Auth
    'google_api_key'       => '',
    // Set it you want google fonts to update weekly. A google_api_key value is required.
    'google_update_weekly' => false,
    // Must be defined to add google fonts to the typography module
    'async_typography'     => false,
    // Use a asynchronous font on the front end or font string
    //'disable_google_fonts_link' => true,                    // Disable this in case you want to create your own google fonts loader
    'admin_bar'            => true,
    // Show the panel pages on the admin bar
    'admin_bar_icon'       => 'dashicons-admin-generic',
    // Choose an icon for the admin bar menu
    'admin_bar_priority'   => 50,
    // Choose an priority for the admin bar menu
    'global_variable'      => '',
    // Set a different name for your global variable other than the opt_name
    'dev_mode'             => true,
    // Show the time the page took to load, etc
    'update_notice'        => true,
    // If dev_mode is enabled, will notify developer of updated versions available in the GitHub Repo
    'customizer'           => true,
    // Enable basic customizer support
    //'open_expanded'     => true,                    // Allow you to start the panel in an expanded way initially.
    //'disable_save_warn' => true,                    // Disable the save warning when a user changes a field
    'show_options_object' => false,
    // OPTIONAL -> Give you extra features
    'page_priority'        => null,
    // Order where the menu appears in the admin area. If there is any conflict, something will not show. Warning.
    'page_parent'          => class_exists('Elementor_Theme_Core') ? $theme->get('TextDomain') : '',
    // For a full list of options, visit: //codex.wordpress.org/Function_Reference/add_submenu_page#Parameters
    'page_permissions'     => 'manage_options',
    // Permissions needed to access the options panel.
    'menu_icon'            => '',
    // Specify a custom URL to an icon
    'last_tab'             => '',
    // Force your panel to always open to a specific tab (by id)
    'page_icon'            => 'icon-themes',
    // Icon displayed in the admin panel next to your menu_title
    'page_slug'            => 'theme-options',
    // Page slug used to denote the panel, will be based off page title then menu title then opt_name if not provided
    'save_defaults'        => true,
    // On load save the defaults to DB before user clicks save or not
    'default_show'         => false,
    // If true, shows the default value next to each field that is not the default value.
    'default_mark'         => '',
    // What to print by the field's title if the value shown is default. Suggested: *
    'show_import_export'   => true,
    // Shows the Import/Export panel when not used as a field.

    // CAREFUL -> These options are for advanced use only
    'transient_time'       => 60 * MINUTE_IN_SECONDS,
    'output'               => true,
    // Global shut-off for dynamic CSS output by the framework. Will also disable google fonts output
    'output_tag'           => true,
    // Allows dynamic CSS to be generated for customizer and google fonts, but stops the dynamic CSS from going to the head
    // 'footer_credit'     => '',                   // Disable the footer credit of Redux. Please leave if you can help it.

    // FUTURE -> Not in use yet, but reserved or partially implemented. Use at your own risk.
    'database'             => '',
    // possible: options, theme_mods, theme_mods_expanded, transient. Not fully functional, warning!
    'use_cdn'              => true,
    // If you prefer not to use the CDN for Select2, Ace Editor, and others, you may download the Redux Vendor Support plugin yourself and run locally or embed it in your code.

    // HINTS
    'hints'                => array(
        'icon'          => 'el el-question-sign',
        'icon_position' => 'right',
        'icon_color'    => 'lightgray',
        'icon_size'     => 'normal',
        'tip_style'     => array(
            'color'   => 'red',
            'shadow'  => true,
            'rounded' => false,
            'style'   => '',
        ),
        'tip_position'  => array(
            'my' => 'top left',
            'at' => 'bottom right',
        ),
        'tip_effect'    => array(
            'show' => array(
                'effect'   => 'slide',
                'duration' => '500',
                'event'    => 'mouseover',
            ),
            'hide' => array(
                'effect'   => 'slide',
                'duration' => '500',
                'event'    => 'click mouseleave',
            ),
        ),
    ),
    'templates_path'       => get_template_directory() . '/inc/templates/redux/'
);

Redux::SetArgs($opt_name, $args);

/*--------------------------------------------------------------
# General
--------------------------------------------------------------*/

Redux::setSection($opt_name, array(
    'title'  => esc_html__('General', 'frontline'),
    'icon'   => 'el-icon-home',
    'fields' => array(
        array(
            'id'       => 'favicon',
            'type'     => 'media',
            'title'    => esc_html__('Favicon', 'frontline'),
            'default' => array(
                'url'=>get_template_directory_uri().'/assets/images/favicon.png'
            )
        ),
        array(
            'id'       => 'show_page_loading',
            'type'     => 'switch',
            'title'    => esc_html__('Enable Page Loading', 'frontline'),
            'subtitle' => esc_html__('Enable page loading effect when you load site.', 'frontline'),
            'default'  => false
        ),
        array(
            'id'       => 'smoothscroll',
            'type'     => 'switch',
            'title'    => esc_html__('Smooth Scroll', 'frontline'),
            'default'  => false
        ),
        array(
            'id'       => 'dev_mode',
            'type'     => 'switch',
            'title'    => esc_html__('Dev Mode (not recommended)', 'frontline'),
            'description' => 'no minimize , generate css over time...',
            'default'  => false
        ),
    )
));

/*--------------------------------------------------------------
# Header
--------------------------------------------------------------*/

Redux::setSection($opt_name, array(
    'title'  => esc_html__('Header', 'frontline'),
    'icon'   => 'el-icon-website',
    'fields' => array(
        array(
            'id'       => 'header_layout',
            'type'     => 'image_select',
            'title'    => esc_html__('Layout', 'frontline'),
            'subtitle' => esc_html__('Select a layout for header.', 'frontline'),
            'options'  => array(
                '1' => get_template_directory_uri() . '/assets/images/header-layout/h1.jpg',
                '2' => get_template_directory_uri() . '/assets/images/header-layout/h2.jpg',
                '3' => get_template_directory_uri() . '/assets/images/header-layout/h3.jpg',
                '4' => get_template_directory_uri() . '/assets/images/header-layout/h4.jpg',
                '5' => get_template_directory_uri() . '/assets/images/header-layout/h5.jpg',
                '6' => get_template_directory_uri() . '/assets/images/header-layout/h6.jpg',
                '7' => get_template_directory_uri() . '/assets/images/header-layout/h7.jpg',
            ),
            'default'  => '1'
        ),
        array(
            'id'       => 'sticky_on',
            'type'     => 'switch',
            'title'    => esc_html__('Sticky Header', 'frontline'),
            'subtitle' => esc_html__('Header will be sticked when applicable.', 'frontline'),
            'default'  => false
        ),
        array(
            'id'       => 'search_on',
            'type'     => 'switch',
            'title'    => esc_html__('Search Icon', 'frontline'),
            'default'  => false
        ),
        array(
            'id'       => 'cart_on',
            'type'     => 'switch',
            'title'    => esc_html__('Cart Icon', 'frontline'),
            'default'  => false
        ),
    )
));


Redux::setSection($opt_name, array(
    'title'      => esc_html__('Logo', 'frontline'),
    'icon'       => 'el el-picture',
    'subsection' => true,
    'fields'     => array(
        array(
            'id'       => 'logo_light',
            'type'     => 'media',
            'title'    => esc_html__('Logo Light', 'frontline'),
            'default' => array(
                'url'=>get_template_directory_uri().'/assets/images/logo-light.png'
            )
        ),
        array(
            'id'       => 'logo',
            'type'     => 'media',
            'title'    => esc_html__('Logo Dark', 'frontline'),
             'default' => array(
                'url'=>get_template_directory_uri().'/assets/images/logo-dark.png'
            )
        ),
        array(
            'id'       => 'logo_mobile',
            'type'     => 'media',
            'title'    => esc_html__('Logo Tablet & Mobile', 'frontline'),
             'default' => array(
                'url'=>get_template_directory_uri().'/assets/images/logo-dark.png'
            )
        ),
        array(
            'id'       => 'logo_maxh',
            'type'     => 'dimensions',
            'title'    => esc_html__('Logo Max height', 'frontline'),
            'subtitle' => esc_html__('Set maximum height for your logo, just in case the logo is too large.', 'frontline'),
            'width'    => false,
            'unit'     => 'px'
        ),
        array(
            'id'       => 'logo_maxh_sm',
            'type'     => 'dimensions',
            'title'    => esc_html__('Logo Max height Tablet & Mobile', 'frontline'),
            'width'    => false,
            'unit'     => 'px'
        ),
    )
));

Redux::setSection($opt_name, array(
    'title'      => esc_html__('Navigation', 'frontline'),
    'icon'       => 'el el-lines',
    'subsection' => true,
    'fields'     => array(
        array(
            'id'          => 'font_menu',
            'type'        => 'typography',
            'title'       => esc_html__('Custom Google Font', 'frontline'),
            'google'      => true,
            'font-backup' => true,
            'all_styles'  => true,
            'font-style'  => false,
            'font-weight'  => true,
            'text-align'  => false,
            'font-size'  => false,
            'line-height'  => false,
            'color'  => false,
            'output'      => array('.primary-menu > li > a, body .primary-menu .sub-menu li a'),
            'units'       => 'px',
        ),
        array(
            'id'       => 'menu_font_size',
            'type'     => 'text',
            'title'    => esc_html__('Font Size', 'frontline'),
            'validate' => 'numeric',
            'desc'     => 'Enter number',
            'msg'      => 'Please enter number',
            'default'  => ''
        ),
        array(
            'id'       => 'menu_text_transform',
            'type'     => 'select',
            'title'    => esc_html__('Text Transform', 'frontline'),
            'options'  => array(
                'uppercase' => esc_html__('Uppercase', 'frontline'),
                'capitalize'  => esc_html__('Capitalize', 'frontline'),
                'lowercase'  => esc_html__('Lowercase', 'frontline'),
                'initial'  => esc_html__('Initial', 'frontline'),
                'inherit'  => esc_html__('Inherit', 'frontline'),
                'none'  => esc_html__('None', 'frontline'),
            ),
            'default'  => ''
        ),
        array(
            'title' => esc_html__('Main Menu', 'frontline'),
            'type'  => 'section',
            'id' => 'main_menu',
            'indent' => true
        ),
        array(
            'id'      => 'main_menu_color',
            'type'    => 'link_color',
            'title'   => esc_html__('Color', 'frontline'),
            'default' => array(
                'regular' => '',
                'hover'   => '',
                'active'   => '',
            ),
        ),
        array(
            'title' => esc_html__('Sticky Menu', 'frontline'),
            'type'  => 'section',
            'id' => 'sticky_menu',
            'indent' => true
        ),
        array(
            'id'      => 'sticky_menu_color',
            'type'    => 'link_color',
            'title'   => esc_html__('Color', 'frontline'),
            'default' => array(
                'regular' => '',
                'hover'   => '',
                'active'   => '',
            ),
        ),
        array(
            'title' => esc_html__('Button Navigation', 'frontline'),
            'type'  => 'section',
            'id' => 'button_navigation',
            'indent' => true
        ),
        array(
            'id'       => 'h_btn_on',
            'type'     => 'button_set',
            'title'    => esc_html__('Show/Hide Button', 'frontline'),
            'options'  => array(
                'show'  => esc_html__('Show', 'frontline'),
                'hide'  => esc_html__('Hide', 'frontline')
            ),
            'default'  => 'hide',
        ),
        array(
            'id' => 'h_btn_text',
            'type' => 'text',
            'title' => esc_html__('Button Text', 'frontline'),
            'default' => '',
            'required' => array( 0 => 'h_btn_on', 1 => 'equals', 2 => 'show' ),
            'force_output' => true
        ),
        array(
            'id'       => 'h_btn_link_type',
            'type'     => 'button_set',
            'title'    => esc_html__('Button Link Type', 'frontline'),
            'options'  => array(
                'page'  => esc_html__('Page', 'frontline'),
                'custom'  => esc_html__('Custom', 'frontline')
            ),
            'default'  => 'page',
            'required' => array( 0 => 'h_btn_on', 1 => 'equals', 2 => 'show' ),
            'force_output' => true
        ),
        array(
            'id'    => 'h_btn_link',
            'type'  => 'select',
            'title' => esc_html__( 'Page Link', 'frontline' ),
            'data'  => 'page',
            'args'  => array(
                'post_type'      => 'page',
                'posts_per_page' => -1,
                'orderby'        => 'title',
                'order'          => 'ASC',
            ),
            'required' => array( 0 => 'h_btn_link_type', 1 => 'equals', 2 => 'page' ),
            'force_output' => true
        ),
        array(
            'id' => 'h_btn_link_custom',
            'type' => 'text',
            'title' => esc_html__('Custom Link', 'frontline'),
            'default' => '',
            'required' => array( 0 => 'h_btn_link_type', 1 => 'equals', 2 => 'custom' ),
            'force_output' => true
        ),
        array(
            'id'       => 'h_btn_target',
            'type'     => 'button_set',
            'title'    => esc_html__('Button Target', 'frontline'),
            'options'  => array(
                '_self'  => esc_html__('Self', 'frontline'),
                '_blank'  => esc_html__('Blank', 'frontline')
            ),
            'default'  => '_self',
            'required' => array( 0 => 'h_btn_on', 1 => 'equals', 2 => 'show' ),
            'force_output' => true
        ),
    )
));
Redux::setSection($opt_name, array(
    'title' => esc_html__('SlideNav & Contact', 'frontline'),
    'icon' => 'el-icon-circle-arrow-right',
    'subsection' => true,
    'fields' => array(
        array(
            'id'       => 'slide_nav_on',
            'type'     => 'button_set',
            'title'    => esc_html__('Show/Hide Button', 'frontline'),
            'subtitle' => 'Show or Hide slide navigation in header',
            'options'  => array(
                'true'  => esc_html__('Show', 'frontline'),
                'false'  => esc_html__('Hide', 'frontline')
            ),
            'default'  => 'false',
        ),
        array(
            'id' => 'slide_logo',
            'type' => 'media',
            'title' => esc_html__('Logo', 'frontline'),
            'subtitle' => 'Slide Navigation Logo',
            'default' => array(
                'url' => get_template_directory_uri() . '/assets/images/logo-dark.png'
            ),
        ),
        array(
            'id' => 'top_slide_desc',
            'type' => 'textarea',
            'title' => esc_html__('Top Slide Desc', 'frontline'),
            'desc' => 'Allow HTML Text',
            'validate' => 'html_custom',
            'default' => '',
            'allowed_html' => array(
                'br' => array(),
                'strong' => array(),
                'span' => array(),
                'p' => array(),
                'i' => array(
                    'class' => array()
                ),
            ),
        ),
        array(
            'id' => 'bottom_slide_desc',
            'type' => 'textarea',
            'title' => esc_html__('Bottom Slide Desc', 'frontline'),
            'desc' => 'Allow HTML Text',
            'validate' => 'html_custom',
            'default' => '',
            'allowed_html' => array(
                'br' => array(),
                'strong' => array(),
                'span' => array(),
                'p' => array(),
                'i' => array(
                    'class' => array()
                ),
            ),
        ),
        array(
            'id' => 'slide_btn_text',
            'type' => 'textarea',
            'title' => esc_html__('Button Text', 'frontline'),
            'validate' => 'html_custom',
            'default' => '',
            'allowed_html' => array(
                'br' => array(),
                'strong' => array(),
                'span' => array(),
                'p' => array(),
                'i' => array(
                    'class' => array()
                ),
            ),
        ),
        array(
            'id' => 'slide_btn_link',
            'type' => 'text',
            'title' => esc_html__('Custom Link', 'frontline'),
            'default' => '',
            'force_output' => true
        ),
        array(
            'title' => esc_html__('Contact Information', 'frontline'),
            'type'  => 'section',
            'id' => 'contact_information',
            'indent' => true
        ),
        array(
            'id' => 'header_note',
            'type' => 'textarea',
            'title' => esc_html__('Note Header', 'frontline'),
            'desc' => 'Allow HTML Text',
            'validate' => 'html_custom',
            'default' => '',
            'allowed_html' => array(
                'br' => array(),
                'strong' => array(),
                'span' => array(),
                'p' => array(),
                'i' => array(
                    'class' => array()
                ),
            ),
        ),
        array(
            'id' => 'ct_address',
            'type' => 'textarea',
            'title' => esc_html__('Address', 'frontline'),
            'desc' => 'Allow HTML Text',
            'validate' => 'html_custom',
            'default' => '',
            'allowed_html' => array(
                'br' => array(),
                'strong' => array(),
                'span' => array(),
                'p' => array(),
                'i' => array(
                    'class' => array()
                ),
            ),
        ),
        array(
            'id' => 'ct_email',
            'type' => 'text',
            'title' => esc_html__('Contact Email', 'frontline'),
            'default' => '',
            'desc' => 'Ex: Frontlinewinner@gmail.com'
        ),
        array(
            'id' => 'time_open',
            'type' => 'textarea',
            'title' => esc_html__('Time Open', 'frontline'),
            'desc' => 'Allow HTML text',
            'validate' => 'html_custom',
            'default' => '',
            'allowed_html' => array(
                'br' => array(),
                'strong' => array(),
                'span' => array(),
                'p' => array(),
                'i' => array(
                    'class' => array()
                ),
            ),
        ),
        array(
            'id' => 'ct_phone',
            'type' => 'text',
            'title' => esc_html__('Contact Phone', 'frontline'),
            'default' => '',
            'desc' => 'Ex: 01654.066.456'
        )
    )
));

/*--------------------------------------------------------------
# Page Title area
--------------------------------------------------------------*/

Redux::setSection($opt_name, array(
    'title'  => esc_html__('Page Title', 'frontline'),
    'icon'   => 'el-icon-map-marker',
    'fields' => array(

        array(
            'id'           => 'pagetitle',
            'type'         => 'button_set',
            'title'        => esc_html__( 'Page Title', 'frontline' ),
            'options'      => array(
                'show'  => esc_html__( 'Show', 'frontline' ),
                'hide'  => esc_html__( 'Hide', 'frontline' ),
            ),
            'default'      => 'show',
        ),

        array(
            'id'       => 'ptitle_layout',
            'type'     => 'image_select',
            'title'    => esc_html__('Layout', 'frontline'),
            'subtitle' => esc_html__('Select a layout for page title.', 'frontline'),
            'options'  => array(
                '1' => get_template_directory_uri() . '/assets/images/ptitle-layout/p1.jpg',
                '2' => get_template_directory_uri() . '/assets/images/ptitle-layout/p2.jpg',
            ),
            'default'  => '1',
            'required' => array( 0 => 'pagetitle', 1 => 'equals', 2 => 'show' ),
            'force_output' => true
        ),

        array(
            'id'       => 'ptitle_bg',
            'type'     => 'background',
            'title'    => esc_html__('Background', 'frontline'),
            'subtitle' => esc_html__('Page title background.', 'frontline'),
            'output'   => array('body #pagetitle'),
            'required' => array( 0 => 'pagetitle', 1 => 'equals', 2 => 'show' ),
            'force_output' => true
        ),
        array(
            'id'       => 'pagetitle_bg_color',
            'type'     => 'color_rgba',
            'title'    => esc_html__('Background Color Overlay', 'frontline'),
            'output' => array('background-color' => 'body #pagetitle.bg-overlay:before'),
            'required' => array( 0 => 'pagetitle', 1 => 'equals', 2 => 'show' ),
            'force_output' => true
        ),
        array(
            'id'       => 'ptitle_color',
            'type'     => 'color',
            'title'    => esc_html__('Title Color', 'frontline'),
            'subtitle' => esc_html__('Page title color.', 'frontline'),
            'output'   => array('body #pagetitle h1.page-title'),
            'default'  => '',
            'transparent' => false,
            'required' => array( 0 => 'pagetitle', 1 => 'equals', 2 => 'show' ),
            'force_output' => true
        ),
        array(
            'id'       => 'ptitle_breadcrumb_on',
            'type'     => 'button_set',
            'title'    => esc_html__('Breadcrumb', 'frontline'),
            'options'  => array(
                'show'  => esc_html__('Show', 'frontline'),
                'hidden'  => esc_html__('Hidden', 'frontline'),
            ),
            'default'  => 'show',
            'required' => array( 0 => 'pagetitle', 1 => 'equals', 2 => 'show' ),
            'force_output' => true
        ),
    )
));

/*--------------------------------------------------------------
# WordPress default content
--------------------------------------------------------------*/

Redux::setSection($opt_name, array(
    'title' => esc_html__('Content', 'frontline'),
    'icon'  => 'el-icon-pencil',
    'fields'     => array(
        array(
            'id'       => 'content_bg_color',
            'type'     => 'color_rgba',
            'title'    => esc_html__('Background Color', 'frontline'),
            'subtitle' => esc_html__('Content background color.', 'frontline'),
            'output' => array('background-color' => 'body')
        ),
        array(
            'id'             => 'content_padding',
            'type'           => 'spacing',
            'output'         => array('#content'),
            'right'   => false,
            'left'    => false,
            'mode'           => 'padding',
            'units'          => array('px'),
            'units_extended' => 'false',
            'title'          => esc_html__('Content Padding', 'frontline'),
            'desc'           => esc_html__('Default: Top 110px, Bottom 110px', 'frontline'),
            'default'            => array(
                'padding-top'   => '',
                'padding-bottom'   => '',
                'units'          => 'px',
            )
        ),
        array(
            'id' => 'content_sidebar_space',
            'type' => 'text',
            'title' => esc_html__('Content & Sidebar Space', 'frontline'),
            'validate' => 'numeric',
            'desc' => 'Enter number (Default 30).',
            'msg' => 'Please enter number',
            'default' => ''
        ),
        array(
            'id'      => 'search_field_placeholder',
            'type'    => 'text',
            'title'   => esc_html__('Search Form - Text Placeholder', 'frontline'),
            'default' => '',
            'desc'           => esc_html__('Default: Search Keywords...', 'frontline'),
        ),
    )
));


Redux::setSection($opt_name, array(
    'title'      => esc_html__('Archive', 'frontline'),
    'icon'       => 'el-icon-list',
    'subsection' => true,
    'fields'     => array(
        array(
            'id'       => 'archive_sidebar_pos',
            'type'     => 'button_set',
            'title'    => esc_html__('Sidebar Position', 'frontline'),
            'subtitle' => esc_html__('Select a sidebar position for blog home, archive, search...', 'frontline'),
            'options'  => array(
                'left'  => esc_html__('Left', 'frontline'),
                'right' => esc_html__('Right', 'frontline'),
                'none'  => esc_html__('Disabled', 'frontline')
            ),
            'default'  => 'right'
        ),
        array(
            'id'       => 'archive_author_on',
            'title'    => esc_html__('Author', 'frontline'),
            'subtitle' => esc_html__('Show author name on each post.', 'frontline'),
            'type'     => 'switch',
            'default'  => false,
        ),
        array(
            'id'       => 'archive_date_on',
            'title'    => esc_html__('Date', 'frontline'),
            'subtitle' => esc_html__('Show date posted on each post.', 'frontline'),
            'type'     => 'switch',
            'default'  => true,
        ),
        array(
            'id' => 'archive_tags_on',
            'title' => esc_html__('Tags', 'frontline'),
            'subtitle' => esc_html__('Show tag names on each post.', 'frontline'),
            'type' => 'switch',
            'default' => true,
        ),
        array(
            'id'       => 'archive_categories_on',
            'title'    => esc_html__('Categories', 'frontline'),
            'subtitle' => esc_html__('Show category names on each post.', 'frontline'),
            'type'     => 'switch',
            'default'  => true,
        ),
        array(
            'id'       => 'archive_comments_on',
            'title'    => esc_html__('Comments', 'frontline'),
            'subtitle' => esc_html__('Show comments count on each post.', 'frontline'),
            'type'     => 'switch',
            'default'  => true,
        ),
    )
));

Redux::setSection($opt_name, array(
    'title'      => esc_html__('Single Post', 'frontline'),
    'icon'       => 'el-icon-file-edit',
    'subsection' => true,
    'fields'     => array(
        array(
            'id'          => 'post_bg_color',
            'type'        => 'color',
            'title'       => esc_html__('Content Background Color', 'frontline'),
            'transparent' => false,
            'default'     => '',
            'required' => array( 0 => 'single_post_layout', 1 => 'equals', 2 => 'real-estate' ),
            'force_output' => true
        ),
        array(
            'id'       => 'post_sidebar_pos',
            'type'     => 'button_set',
            'title'    => esc_html__('Sidebar Position', 'frontline'),
            'subtitle' => esc_html__('Select a sidebar position', 'frontline'),
            'options'  => array(
                'left'  => esc_html__('Left', 'frontline'),
                'right' => esc_html__('Right', 'frontline'),
                'none'  => esc_html__('Disabled', 'frontline')
            ),
            'default'  => 'right'
        ),
        array(
            'id'       => 'post_author_on',
            'title'    => esc_html__('Author', 'frontline'),
            'subtitle' => esc_html__('Show author name on single post.', 'frontline'),
            'type'     => 'switch',
            'default'  => false
        ),
        array(
            'id'       => 'post_date_on',
            'title'    => esc_html__('Date', 'frontline'),
            'subtitle' => esc_html__('Show date on single post.', 'frontline'),
            'type'     => 'switch',
            'default'  => true
        ),
        array(
            'id'       => 'post_categories_on',
            'title'    => esc_html__('Categories', 'frontline'),
            'subtitle' => esc_html__('Show category names on single post.', 'frontline'),
            'type'     => 'switch',
            'default'  => false
        ),
        array(
            'id'       => 'post_tags_on',
            'title'    => esc_html__('Tags', 'frontline'),
            'subtitle' => esc_html__('Show tag names on single post.', 'frontline'),
            'type'     => 'switch',
            'default'  => true
        ),
        array(
            'id'       => 'post_comments_on',
            'title'    => esc_html__('Comments', 'frontline'),
            'subtitle' => esc_html__('Show comments count on single post.', 'frontline'),
            'type'     => 'switch',
            'default'  => true
        ),
        array(
            'id'       => 'post_view_on',
            'title'    => esc_html__('Post View', 'frontline'),
            'subtitle' => esc_html__('Show post view count on single post.', 'frontline'),
            'type'     => 'switch',
            'default'  => false,
        ),
        array(
            'id'       => 'post_social_share_on',
            'title'    => esc_html__('Social Share', 'frontline'),
            'subtitle' => esc_html__('Show social share on single post.', 'frontline'),
            'type'     => 'switch',
            'default'  => false,
        ),
        array(
            'id'       => 'post_comments_form_on',
            'title'    => esc_html__('Comments Form', 'frontline'),
            'subtitle' => esc_html__('Show comments form on single post.', 'frontline'),
            'type'     => 'switch',
            'default'  => true
        ),
        array(
            'id'       => 'post_feature_image_on',
            'title'    => esc_html__('Feature Image', 'frontline'),
            'subtitle' => esc_html__('Show feature image on single post.', 'frontline'),
            'type'     => 'switch',
            'default'  => true
        ),
    )
));
Redux::setSection($opt_name, array(
    'title' => esc_html__('Single Case Study', 'frontline'),
    'icon' => 'el el-briefcase',
    'subsection' => true,
    'fields' => array(
        array(
            'id' => 'portfolio_sidebar_pos',
            'type' => 'button_set',
            'title' => esc_html__('Sidebar Position', 'frontline'),
            'subtitle' => esc_html__('Select a sidebar position', 'frontline'),
            'options' => array(
                'left' => esc_html__('Left', 'frontline'),
                'right' => esc_html__('Right', 'frontline'),
                'none' => esc_html__('Disabled', 'frontline')
            ),
            'default' => 'right'
        ),
        array(
            'id' => 'portfolio_slug',
            'type' => 'text',
            'title' => esc_html__('Slug', 'frontline'),
            'default' => '',
            'subtitle' => esc_html__('The slug name cannot be the same as a page name. Make sure to regenertate permalinks, after making changes.', 'frontline'),
        ),
    )
));
Redux::setSection($opt_name, array(
    'title' => esc_html__('Single Practice Area', 'frontline'),
    'icon' => 'el el-tasks',
    'subsection' => true,
    'fields' => array(
        array(
            'id' => 'area_sidebar_pos',
            'type' => 'button_set',
            'title' => esc_html__('Sidebar Position', 'frontline'),
            'subtitle' => esc_html__('Select a sidebar position', 'frontline'),
            'options' => array(
                'left' => esc_html__('Left', 'frontline'),
                'right' => esc_html__('Right', 'frontline'),
                'none' => esc_html__('Disabled', 'frontline')
            ),
            'default' => 'right'
        ),
        array(
            'id' => 'area_slug',
            'type' => 'text',
            'title' => esc_html__('Slug', 'frontline'),
            'default' => '',
            'subtitle' => esc_html__('The slug name cannot be the same as a page name. Make sure to regenertate permalinks, after making changes.', 'frontline'),
        ),
    )
));

/*--------------------------------------------------------------
# Shop
--------------------------------------------------------------*/
if(class_exists('Woocommerce')) {
    Redux::setSection($opt_name, array(
        'title'  => esc_html__('Shop', 'frontline'),
        'icon'   => 'el el-shopping-cart',
        'fields' => array(
            array(
                'id'       => 'sidebar_shop',
                'type'     => 'button_set',
                'title'    => esc_html__('Sidebar Position', 'frontline'),
                'subtitle' => esc_html__('Select a sidebar position for archive shop.', 'frontline'),
                'options'  => array(
                    'left'  => esc_html__('Left', 'frontline'),
                    'right' => esc_html__('Right', 'frontline'),
                    'none'  => esc_html__('Disabled', 'frontline')
                ),
                'default'  => 'right'
            ),
            array(
                'title' => esc_html__('Products displayed per page', 'frontline'),
                'id' => 'product_per_page',
                'type' => 'slider',
                'subtitle' => esc_html__('Number product to show', 'frontline'),
                'default' => 6,
                'min'  => 3,
                'step' => 1,
                'max' => 50,
                'display_value' => 'text'
            ),
            array(
                'id' => 'product_per_row',
                'type' => 'button_set',
                'title' => esc_html__('Product per row', 'frontline'),
                'options' => array(
                    '3' => esc_html__('3 Column', 'frontline'),
                    '4' => esc_html__('4 Column', 'frontline'),
                    '5' => esc_html__('5 Column', 'frontline'),
                ),
                'default' => '3',
                'force_output' => true
            ),
            array(
                'id' => 'shop_content_padding',
                'type' => 'spacing',
                'title' => esc_html__('Content Paddings', 'frontline'),
                'subtitle' => esc_html__('Content paddings.', 'frontline'),
                'mode' => 'padding',
                'units' => array('em', 'px', '%'),
                'top' => true,
                'right' => false,
                'bottom' => true,
                'left' => false,
                'output' => array('.woocommerce #content, .woocommerce-page #content'),
                'default' => array(
                    'top' => '',
                    'right' => '',
                    'bottom' => '',
                    'left' => '',
                    'units' => 'px',
                )
            )
        )
    ));
}

/*--------------------------------------------------------------
# Footer
--------------------------------------------------------------*/

Redux::setSection($opt_name, array(
    'title'  => esc_html__('Footer', 'frontline'),
    'icon'   => 'el el-website',
    'fields' => array(
        array(
            'id'       => 'footer_layout',
            'type'     => 'button_set',
            'title'    => esc_html__('Layout', 'frontline'),
            'subtitle' => esc_html__('Select a layout for upper footer area.', 'frontline'),
            'options'  => array(
                '1'  => esc_html__('Default', 'frontline'),
                'custom'  => esc_html__('Custom', 'frontline'),
                '0'  => esc_html__('No Footer', 'frontline'),
            ),
            'default'  => '1'
        ),
        array(
            'id'          => 'footer_layout_custom',
            'type'        => 'select',
            'title'       => esc_html__('Custom Layout', 'frontline'),
            'desc'        => sprintf(esc_html__('To use this Option please %sClick Here%s to add your custom footer layout first.','frontline'),'<a href="' . esc_url( admin_url( 'edit.php?post_type=footer' ) ) . '">','</a>'),
            'options'     => frontline_list_post('footer'),
            'default'     => '',
            'required' => array( 0 => 'footer_layout', 1 => 'equals', 2 => 'custom' ),
            'force_output' => true
        ),
        array(
            'id' => 'back_totop_on',
            'type' => 'switch',
            'title' => esc_html__('Back to Top Button', 'frontline'),
            'subtitle' => esc_html__('Show back to top button when scrolled down.', 'frontline'),
            'default' => true
        ),
    )
));

Redux::setSection($opt_name, array(
    'title'      => esc_html__('Footer Top', 'frontline'),
    'icon'       => 'el el-circle-arrow-right',
    'subsection' => true,
    'fields'     => array(
        array(
            'id'       => 'footer_top_column',
            'type'     => 'button_set',
            'title'    => esc_html__('Columns', 'frontline'),
            'options'  => array(
                '2'  => esc_html__('2 Column', 'frontline'),
                '3'  => esc_html__('3 Column', 'frontline'),
                '4'  => esc_html__('4 Column', 'frontline'),
            ),
            'default'  => '4',
        ),
        array(
            'id'    => 'footer_top_color',
            'type'  => 'color',
            'title' => esc_html__('Text Color', 'frontline'),
            'output'   => array('.top-footer')
        ),
        array(
            'id'      => 'footer_top_link_color',
            'type'    => 'link_color',
            'title'   => esc_html__('Links Color', 'frontline'),
            'regular' => true,
            'hover'   => true,
            'active'  => true,
            'visited' => true,
            'output'  => array('.top-footer a'),
        ),
        array(
            'title' => esc_html__('Widget Title', 'frontline'),
            'type'  => 'section',
            'id' => 'footer_wg_title',
            'indent' => true,
        ),
        array(
            'id'    => 'footer_top_heading_color',
            'type'  => 'color',
            'title' => esc_html__('Title Color', 'frontline'),
        ),
    )
));

Redux::setSection($opt_name, array(
    'title'      => esc_html__('Footer Bottom', 'frontline'),
    'icon'       => 'el el-circle-arrow-right',
    'subsection' => true,
    'fields'     => array(
        array(
            'id'=>'footer_copyright',
            'type' => 'textarea',
            'title' => esc_html__('Copyright', 'frontline'),
            'validate' => 'html_custom',
            'default' => '',
            'allowed_html' => array(
                'a' => array(
                    'href' => array(),
                    'title' => array(),
                    'class' => array(),
                ),
                'br' => array(),
                'em' => array(),
                'strong' => array(),
                'span' => array(),
                'p' => array(),
                'div' => array(
                    'class' => array()
                ),
                'h1' => array(
                    'class' => array()
                ),
                'h2' => array(
                    'class' => array()
                ),
                'h3' => array(
                    'class' => array()
                ),
                'h4' => array(
                    'class' => array()
                ),
                'h5' => array(
                    'class' => array()
                ),
                'h6' => array(
                    'class' => array()
                ),
                'ul' => array(
                    'class' => array()
                ),
                'li' => array(),
            )
        ),
        array(
            'id'    => 'footer_bottom_menu',
            'type'  => 'select',
            'title' => esc_html__( 'Select Menu', 'frontline' ),
            'data'  => 'menus',
            'args'  => array(
                'hide_empty' => false,
                'orderby'    => 'name',
            )
        ),
    )
));


/*--------------------------------------------------------------
# Colors
--------------------------------------------------------------*/

Redux::setSection($opt_name, array(
    'title'  => esc_html__('Colors', 'frontline'),
    'icon'   => 'el-icon-file-edit',
    'fields' => array(
        array(
            'id'          => 'primary_color',
            'type'        => 'color',
            'title'       => esc_html__('Primary Color', 'frontline'),
            'transparent' => false,
            'default'     => '#ccbd99'
        ),
        array(
            'id' => 'secondary_color',
            'type' => 'color',
            'title' => esc_html__('Secondary Color', 'frontline'),
            'transparent' => false,
            'default' => '#1c1c23'
        ),
        array(
            'id'      => 'link_color',
            'type'    => 'link_color',
            'title'   => esc_html__('Link Colors', 'frontline'),
            'default' => array(
                'regular' => '#777777',
                'hover'   => '#ccbd99',
                'active'  => '#ccbd99'
            ),
            'output'  => array('a')
        )
    )
));

/*--------------------------------------------------------------
# Typography
--------------------------------------------------------------*/
$custom_font_selectors_1 = Redux::getOption($opt_name, 'custom_font_selectors_1');
$custom_font_selectors_1 = !empty($custom_font_selectors_1) ? explode(',', $custom_font_selectors_1) : array();
Redux::setSection($opt_name, array(
    'title'  => esc_html__('Typography', 'frontline'),
    'icon'   => 'el-icon-text-width',
    'fields' => array(
        array(
            'id'       => 'body_default_font',
            'type'     => 'select',
            'title'    => esc_html__('Body Default Font', 'frontline'),
            'options'  => array(
                'Futura'  => esc_html__('Default', 'frontline'),
                'Google-Font'  => esc_html__('Google Font', 'frontline'),
            ),
            'default'  => 'Futura',
        ),
        array(
            'id'          => 'font_main',
            'type'        => 'typography',
            'title'       => esc_html__('Body Google Font', 'frontline'),
            'subtitle'    => esc_html__('This will be the default font of your website.', 'frontline'),
            'google'      => true,
            'font-backup' => true,
            'all_styles'  => true,
            'line-height'  => true,
            'font-size'  => true,
            'text-align'  => false,
            'output'      => array('body'),
            'units'       => 'px',
            'required' => array( 0 => 'body_default_font', 1 => 'equals', 2 => 'Google-Font' ),
            'force_output' => true
        ),
        array(
            'id'       => 'heading_default_font',
            'type'     => 'select',
            'title'    => esc_html__('Heading Default Font', 'frontline'),
            'options'  => array(
                'Playfair Display'  => esc_html__('Default', 'frontline'),
                'Google-Font'  => esc_html__('Google Font', 'frontline'),
            ),
            'default'  => 'Playfair Display',
        ),
        array(
            'id'          => 'font_h1',
            'type'        => 'typography',
            'title'       => esc_html__('H1', 'frontline'),
            'subtitle'    => esc_html__('This will be the default font for all H1 tags of your website.', 'frontline'),
            'google'      => true,
            'font-backup' => true,
            'all_styles'  => true,
            'text-align'  => false,
            'output'      => array('h1', '.h1', '.text-heading'),
            'units'       => 'px',
            'required' => array( 0 => 'heading_default_font', 1 => 'equals', 2 => 'Google-Font' ),
            'force_output' => true
        ),
        array(
            'id'          => 'font_h2',
            'type'        => 'typography',
            'title'       => esc_html__('H2', 'frontline'),
            'subtitle'    => esc_html__('This will be the default font for all H2 tags of your website.', 'frontline'),
            'google'      => true,
            'font-backup' => true,
            'all_styles'  => true,
            'text-align'  => false,
            'output'      => array('h2', '.h2'),
            'units'       => 'px',
            'required' => array( 0 => 'heading_default_font', 1 => 'equals', 2 => 'Google-Font' ),
            'force_output' => true
        ),
        array(
            'id'          => 'font_h3',
            'type'        => 'typography',
            'title'       => esc_html__('H3', 'frontline'),
            'subtitle'    => esc_html__('This will be the default font for all H3 tags of your website.', 'frontline'),
            'google'      => true,
            'font-backup' => true,
            'all_styles'  => true,
            'text-align'  => false,
            'output'      => array('h3', '.h3'),
            'units'       => 'px',
            'required' => array( 0 => 'heading_default_font', 1 => 'equals', 2 => 'Google-Font' ),
            'force_output' => true
        ),
        array(
            'id'          => 'font_h4',
            'type'        => 'typography',
            'title'       => esc_html__('H4', 'frontline'),
            'subtitle'    => esc_html__('This will be the default font for all H4 tags of your website.', 'frontline'),
            'google'      => true,
            'font-backup' => true,
            'all_styles'  => true,
            'text-align'  => false,
            'output'      => array('h4', '.h4'),
            'units'       => 'px',
            'required' => array( 0 => 'heading_default_font', 1 => 'equals', 2 => 'Google-Font' ),
            'force_output' => true
        ),
        array(
            'id'          => 'font_h5',
            'type'        => 'typography',
            'title'       => esc_html__('H5', 'frontline'),
            'subtitle'    => esc_html__('This will be the default font for all H5 tags of your website.', 'frontline'),
            'google'      => true,
            'font-backup' => true,
            'all_styles'  => true,
            'text-align'  => false,
            'output'      => array('h5', '.h5'),
            'units'       => 'px',
            'required' => array( 0 => 'heading_default_font', 1 => 'equals', 2 => 'Google-Font' ),
            'force_output' => true
        ),
        array(
            'id'          => 'font_h6',
            'type'        => 'typography',
            'title'       => esc_html__('H6', 'frontline'),
            'subtitle'    => esc_html__('This will be the default font for all H6 tags of your website.', 'frontline'),
            'google'      => true,
            'font-backup' => true,
            'all_styles'  => true,
            'text-align'  => false,
            'output'      => array('h6', '.h6'),
            'units'       => 'px',
            'required' => array( 0 => 'heading_default_font', 1 => 'equals', 2 => 'Google-Font' ),
            'force_output' => true
        ),
        array(
            'id'       => 'sub_heading_default_font',
            'type'     => 'select',
            'title'    => esc_html__('Sub Heading Default Font', 'frontline'),
            'options'  => array(
                'Shadows-Into-Light'  => esc_html__('Default', 'frontline'),
                'Google-Font'  => esc_html__('Google Font', 'frontline'),
            ),
            'default'  => 'Shadows-Into-Light',
        ),
        array(
            'id'          => 'font_sub_heading',
            'type'        => 'typography',
            'title'       => esc_html__('Body Google Font', 'frontline'),
            'subtitle'    => esc_html__('This will be the default font of your website.', 'frontline'),
            'google'      => true,
            'font-backup' => false,
            'all_styles'  => false,
            'line-height'  => false,
            'font-size'  => false,
            'color'  => false,
            'font-weight'  => false,
            'text-align'  => false,
            'output'      => array('body .ft-sub'),
            'units'       => 'px',
            'required' => array( 0 => 'sub_heading_default_font', 1 => 'equals', 2 => 'Google-Font' ),
            'force_output' => true
        ),
    )
));

Redux::setSection($opt_name, array(
    'title'      => esc_html__('Fonts Selectors', 'frontline'),
    'icon'       => 'el el-fontsize',
    'subsection' => true,
    'fields'     => array(
        array(
            'id'          => 'custom_font_1',
            'type'        => 'typography',
            'title'       => esc_html__('Custom Font', 'frontline'),
            'subtitle'    => esc_html__('This will be the font that applies to the class selector.', 'frontline'),
            'google'      => true,
            'font-backup' => true,
            'all_styles'  => true,
            'text-align'  => false,
            'output'      => $custom_font_selectors_1,
            'units'       => 'px',

        ),
        array(
            'id'       => 'custom_font_selectors_1',
            'type'     => 'textarea',
            'title'    => esc_html__('CSS Selectors', 'frontline'),
            'subtitle' => esc_html__('Add class selectors to apply above font.', 'frontline'),
            'validate' => 'no_html'
        )
    )
));

/* Google Maps /--------------------------------------------------------- */
Redux::setSection($opt_name, array(
    'title'  => esc_html__('Google Maps', 'frontline'),
    'icon'   => 'el el-map-marker',
    'fields' => array(
        array(
            'id'       => 'gm_api_key',
            'type'     => 'text',
            'title'    => esc_html__('API Key', 'frontline'),
            'default' => 'AIzaSyC08_qdlXXCWiFNVj02d-L2BDK5qr6ZnfM',
            'desc' => esc_html__('Register a Google Maps Api key then put it in here.', 'frontline')
        ),
    ),
));

/* 404 Page /--------------------------------------------------------- */
Redux::setSection($opt_name, array(
    'title'  => esc_html__('404 Page', 'frontline'),
    'icon'   => 'el-cog-alt el',
    'fields' => array(
        array(
            'id'       => 'icon_404',
            'type'     => 'media',
            'title'    => esc_html__('Icon', 'frontline'),
        ),
        array(
            'id'       => 'subtitle_404',
            'type'     => 'text',
            'title'    => esc_html__('Subtitle', 'frontline'),
            'default' => '',
            'desc' => esc_html__('Default: OOPS! PAGE NOT FOUND!', 'frontline')
        ),
        array(
            'id'       => 'content_404_page',
            'type'     => 'textarea',
            'title'    => esc_html__('Content', 'frontline'),
            'default' => '',
        ),
        array(
            'id'       => 'btn_text_404_page',
            'type'     => 'text',
            'title'    => esc_html__('Button Text', 'frontline'),
            'default' => '',
            'desc' => esc_html__('Default: Back To HomePage', 'frontline')
        ),
        array(
            'id'       => 'bg_404_page',
            'type'     => 'background',
            'title'    => esc_html__('Background', 'frontline'),
            'output'   => array('body.error404 .error-404'),
            'background-color' => false
        ),
    ),
));

/* Social Media */
Redux::setSection($opt_name, array(
    'title' => esc_html__('Social Media', 'frontline'),
    'icon' => 'el el-twitter',
    'subsection' => false,
    'fields' => array(
        array(
            'id' => 'social_media',
            'type' => 'sorter',
            'title' => 'Enable and Sort',
            'desc' => 'Choose which social networks are displayed and edit where they link to.',
            'options' => array(
                'enabled' => array(
                    'facebook' => 'Facebook',
                    'instagram' => 'Instagram',
                    'twitter' => 'Twitter',
                ),
                'disabled' => array(
                    'tripadvisor' => 'Tripadvisor',
                    'google' => 'Google',
                    'youtube' => 'Youtube',
                    'vimeo' => 'Vimeo',
                    'tumblr' => 'Tumblr',
                    'pinterest' => 'Pinterest',
                    'yelp' => 'Yelp',
                    'skype' => 'Skype',
                    'linkedin' => 'Linkedin',
                    'rss' => 'Rss',
                )
            ),
        ),
        array(
            'id'      => 'social_facebook_url',
            'type'    => 'text',
            'title'   => esc_html__('Facebook URL', 'frontline'),
            'default' => '',
        ),
        array(
            'id'      => 'social_twitter_url',
            'type'    => 'text',
            'title'   => esc_html__('Twitter URL', 'frontline'),
            'default' => '',
        ),
        array(
            'id'      => 'social_inkedin_url',
            'type'    => 'text',
            'title'   => esc_html__('Inkedin URL', 'frontline'),
            'default' => '',
        ),
        array(
            'id'      => 'social_rss_url',
            'type'    => 'text',
            'title'   => esc_html__('Rss URL', 'frontline'),
            'default' => '',
        ),
        array(
            'id'      => 'social_instagram_url',
            'type'    => 'text',
            'title'   => esc_html__('Instagram URL', 'frontline'),
            'default' => '',
        ),
        array(
            'id'      => 'social_google_url',
            'type'    => 'text',
            'title'   => esc_html__('Google URL', 'frontline'),
            'default' => '',
        ),
        array(
            'id'      => 'social_skype_url',
            'type'    => 'text',
            'title'   => esc_html__('Skype URL', 'frontline'),
            'default' => '',
        ),
        array(
            'id'      => 'social_pinterest_url',
            'type'    => 'text',
            'title'   => esc_html__('Pinterest URL', 'frontline'),
            'default' => '',
        ),
        array(
            'id'      => 'social_vimeo_url',
            'type'    => 'text',
            'title'   => esc_html__('Vimeo URL', 'frontline'),
            'default' => '',
        ),
        array(
            'id'      => 'social_youtube_url',
            'type'    => 'text',
            'title'   => esc_html__('Youtube URL', 'frontline'),
            'default' => '',
        ),
        array(
            'id'      => 'social_yelp_url',
            'type'    => 'text',
            'title'   => esc_html__('Yelp URL', 'frontline'),
            'default' => '',
        ),
        array(
            'id'      => 'social_tumblr_url',
            'type'    => 'text',
            'title'   => esc_html__('Tumblr URL', 'frontline'),
            'default' => '',
        ),
        array(
            'id'      => 'social_tripadvisor_url',
            'type'    => 'text',
            'title'   => esc_html__('Tripadvisor URL', 'frontline'),
            'default' => '',
        ),
    )
));

/* Custom Code /--------------------------------------------------------- */
Redux::setSection($opt_name, array(
    'title'  => esc_html__('Custom Code', 'frontline'),
    'icon'   => 'el-icon-edit',
    'fields' => array(

        array(
            'id'       => 'site_header_code',
            'type'     => 'textarea',
            'theme'    => 'chrome',
            'title'    => esc_html__('Header Custom Codes', 'frontline'),
            'subtitle' => esc_html__('It will insert the code to wp_head hook.', 'frontline'),
        ),
        array(
            'id'       => 'site_footer_code',
            'type'     => 'textarea',
            'theme'    => 'chrome',
            'title'    => esc_html__('Footer Custom Codes', 'frontline'),
            'subtitle' => esc_html__('It will insert the code to wp_footer hook.', 'frontline'),
        ),

    ),
));

/* Custom CSS /--------------------------------------------------------- */
Redux::setSection($opt_name, array(
    'title'  => esc_html__('Custom CSS', 'frontline'),
    'icon'   => 'el-icon-adjust-alt',
    'fields' => array(

        array(
            'id'   => 'customcss',
            'type' => 'info',
            'desc' => esc_html__('Custom CSS', 'frontline')
        ),

        array(
            'id'       => 'site_css',
            'type'     => 'ace_editor',
            'title'    => esc_html__('CSS Code', 'frontline'),
            'subtitle' => esc_html__('Advanced CSS Options. You can paste your custom CSS Code here.', 'frontline'),
            'mode'     => 'css',
            'validate' => 'css',
            'theme'    => 'chrome',
            'default'  => ""
        ),

    ),
));