<?php defined( 'ABSPATH' ) or exit( -1 );
/**
 * Case Study Info widgets
 *
 * @package Frontline
 * @version 1.0
 */

class CMS_Case_Study_Info_Widget extends WP_Widget
{
    function __construct()
    {
        parent::__construct(
            'cms_case_study_info',
            esc_html__( '* Case Study Info Meta', 'frontline' ),
            array(
                'description' => __( 'Shows info meta of case study.', 'frontline' ),
            )
        );
    }

    /**
     * Outputs the HTML for this widget.
     *
     * @param array $args An array of standard parameters for widgets in this theme
     * @param array $instance An array of settings for this widget instance
     * @return void Echoes it's output
     **/
    function widget( $args, $instance )
    {
        if (!is_singular('portfolio')){
            return false;
        }
        $instance = wp_parse_args( (array) $instance, array(
            'show_info_text'     => true,
            'show_social_share'     => true,
            'show_download_button' => true
        ) );
        $show_info_text     = (bool)$instance['show_info_text'];
        $show_social_share     = (bool)$instance['show_social_share'];
        $show_download_button = (bool)$instance['show_download_button'];
        $post_ID = get_the_ID();
        $client = frontline_get_page_opt('wg_client');
        $date = frontline_get_page_opt('wg_date');
        $website = frontline_get_page_opt('wg_website');
        $category = frontline_get_page_opt('wg_category');
        $awarded = frontline_get_page_opt('wg_awarded');
        $awarded_desc = frontline_get_page_opt('wg_awarded_desc');
        $wg_download_1 = frontline_get_page_opt('wg_download_1');
        $wg_download_2 = frontline_get_page_opt('wg_download_2');

        ?>
        <div class="cms-case-study-info widget font-smooth">
            <?php if($show_info_text) : ?>
            <div class="info-text">
                <div class="info-text-top">
                    <?php if($client) : ?>
                        <div class="info-item client">
                            <p><?php echo esc_html__('CLIENT', 'frontline').' '.':'; ?></p>
                            <p><?php echo esc_html($client); ?></p>
                        </div>
                    <?php endif; ?>

                    <?php if($date) : ?>
                        <div class="info-item">
                            <p><?php echo esc_html__('DATE', 'frontline').' '.':'; ?></p>
                            <p><?php echo esc_html($date); ?></p>
                        </div>
                    <?php endif; ?>

                    <?php if($website) : ?>
                        <div class="info-item">
                            <p><?php echo esc_html__('WEBSITE', 'frontline').' '.':'; ?></p>
                            <p><?php echo esc_html($website); ?></p>
                        </div>
                    <?php endif; ?>

                    <?php if($category) : ?>
                        <div class="info-item">
                            <p><?php echo esc_html__('CATEGORY', 'frontline').' '.':'; ?></p>
                            <p><?php echo esc_html($category); ?></p>
                        </div>
                    <?php endif; ?>
                </div>
                <div class="info-text-bottom">
                    <?php if($awarded) : ?>
                        <div class="info-item">
                            <p><?php echo esc_html__('AWARDED', 'frontline').' '.':'; ?></p>
                            <p><?php echo esc_html($awarded); ?></p>
                        </div>
                        <?php if($awarded_desc) : ?>
                            <p class="awarded-desc"><?php echo esc_html($awarded_desc); ?></p>
                        <?php endif; ?>
                    <?php endif; ?>
                </div>
            </div>
            <?php endif; ?>

            <?php if($show_social_share) : ?>
            <div class="info-share">
                <div class="info-item">
                    <p><?php echo esc_html__('SHARE', 'frontline').' '.':'; ?></p>
                    <ul class="portfolio-share">
                        <li><a class="fb-social" title="<?php echo esc_attr__('Share On Facebook', 'frontline'); ?>" target="_blank" href="https://www.facebook.com/sharer/sharer.php?u=<?php echo esc_url( get_permalink($post_ID) ); ?>"><i class="zmdi zmdi-facebook"></i></a></li>
                        <li><a class="pin-social" title="<?php echo esc_attr__('Share On Pinterest', 'frontline'); ?>" target="_blank" href="https://pinterest.com/pin/create/button/?url=<?php echo get_the_post_thumbnail_url($post_ID,'full'); ?>&media=&description=<?php echo urlencode(the_title_attribute(array('post'=>$post_ID, 'echo'=>false))); ?>"><i class="zmdi zmdi-pinterest-box"></i></a></li>
                        <li><a class="tw-social" title="<?php echo esc_attr__('Share On Twitter', 'frontline'); ?>" target="_blank" href="https://twitter.com/home?status=<?php echo esc_url( get_permalink($post_ID) ); ?>"><i class="zmdi zmdi-twitter"></i></a></li>
                        <li><a class="g-social" title="<?php echo esc_attr__('Share On Google+', 'frontline'); ?>" target="_blank" href="https://plus.google.com/share?url=<?php the_permalink(); ?>"><i class="fa fa-google-plus" aria-hidden="true"></i></a></li>
                    </ul>
                </div>
            </div>
            <?php endif; ?>

            <?php if($show_download_button) : ?>
            <div class="info-buttons">
                <?php if($wg_download_1) : ?>
                    <p><?php echo wp_kses_post($wg_download_1); ?></p>
                <?php endif; ?>

                <?php if($wg_download_2) : ?>
                    <p><?php echo wp_kses_post($wg_download_2); ?></p>
                <?php endif; ?>
            </div>
            <?php endif; ?>
        </div>
        <?php
    }

    /**
     * Deals with the settings when they are saved by the admin. Here is
     * where any validation should be dealt with.
     *
     * @param array $new_instance An array of new settings as submitted by the admin
     * @param array $old_instance An array of the previous settings
     * @return array The validated and (if necessary) amended settings
     **/
    function update( $new_instance, $old_instance )
    {
        $instance = $old_instance;
        $instance['show_info_text']     = (bool)$new_instance['show_info_text'] ;
        $instance['show_social_share']     = (bool)$new_instance['show_social_share'] ;
        $instance['show_download_button']     = (bool)$new_instance['show_download_button'] ;
        return $instance;
    }

    /**
     * Displays the form for this widget on the Widgets page of the WP Admin area.
     *
     * @param array $instance An array of the current settings for this widget
     * @return void Echoes it's output
     **/
    function form( $instance )
    {
        $instance = wp_parse_args( (array) $instance, array(
            'show_info_text'     => true,
            'show_social_share'     => true,
            'show_download_button'     => true
        ) );

        $show_info_text     = (bool) $instance['show_info_text'];
        $show_social_share     = (bool) $instance['show_social_share'];
        $show_download_button     = (bool) $instance['show_download_button'];

        ?>
        <p>
            <input class="checkbox" type="checkbox"<?php checked( $show_info_text ); ?> id="<?php echo esc_attr( $this->get_field_id( 'show_info_text' ) ); ?>" name="<?php echo esc_attr( $this->get_field_name( 'show_info_text' ) ); ?>" value="1" />
            <label for="<?php echo esc_attr( $this->get_field_id( 'show_info_text' ) ); ?>"><?php esc_html_e( 'Show Info Text?', 'frontline' ); ?></label>
        </p>

        <p>
            <input class="checkbox" type="checkbox"<?php checked( $show_social_share ); ?> id="<?php echo esc_attr( $this->get_field_id( 'show_social_share' ) ); ?>" name="<?php echo esc_attr( $this->get_field_name( 'show_social_share' ) ); ?>" value="1" />
            <label for="<?php echo esc_attr( $this->get_field_id( 'show_social_share' ) ); ?>"><?php esc_html_e( 'Show Social Share?', 'frontline' ); ?></label>
        </p>

        <p>
            <input class="checkbox" type="checkbox"<?php checked( $show_download_button ); ?> id="<?php echo esc_attr( $this->get_field_id( 'show_download_button' ) ); ?>" name="<?php echo esc_attr( $this->get_field_name( 'show_download_button' ) ); ?>" value="1" />
            <label for="<?php echo esc_attr( $this->get_field_id( 'show_download_button' ) ); ?>"><?php esc_html_e( 'Show Download Button?', 'frontline' ); ?></label>
        </p>

        <?php
    }
}

function register_case_study_info_widget()
{
    global $wp_widget_factory;
    $wp_widget_factory->register( 'CMS_Case_Study_Info_Widget' );
}

add_action('widgets_init', 'register_case_study_info_widget'); ?>