<?php

class CMS_contact_phone_Widget extends WP_Widget
{

    function __construct()
    {
        parent::__construct(
            'cms_contact_phone_widget',
            esc_html__('* Contact Phone', 'frontline'),
            array('description' => esc_html__('Contact Phone Widget', 'frontline'),)
        );
    }

    function widget($args, $instance)
    {
        extract($args);
        $icon_img_id = isset($instance['icon_img']) ? (!empty($instance['icon_img']) ? $instance['icon_img'] : '') : '';
        $icon_img = wp_get_attachment_image($icon_img_id);
        $title = isset($instance['title']) ? (!empty($instance['title']) ? $instance['title'] : '') : '';
        $phone_text = isset($instance['phone_text']) ? (!empty($instance['phone_text']) ? $instance['phone_text']: '') : '';
        $phone_text_href = str_replace(array( ' ','+' ), '', $phone_text);
        $description = isset($instance['description']) ? (!empty($instance['description']) ? $instance['description'] : '') : '';
        $button_text = isset($instance['button_text']) ? $instance['button_text'] : '';
        $button_link = isset($instance['button_link']) ? $instance['button_link'] : '';
        ?>
        <div class="cms-contact-phone widget">
            <div class="content-top">
                <?php if (!empty($icon_img)) : ?>
                    <div class="ct-icon">
                        <?php echo wp_kses_post($icon_img); ?>
                    </div>
                <?php endif; ?>

                <?php if (!empty($title)) : ?>
                    <div class="ct-title font-smooth">
                        <h4><?php echo wp_kses_post($title); ?></h4>
                    </div>
                <?php endif; ?>

                <?php if(!empty($phone_text)): ?>
                    <div class="ct-phone">
                        <p><a href="tel:<?php echo esc_attr( $phone_text_href ); ?>"><?php echo wp_kses_post( $phone_text  ); ?></a></p>
                    </div>
                <?php endif; ?>

                <?php if (!empty($description)): ?>
                    <div class="ct-description font-smooth">
                        <p><?php echo wp_kses_post($description); ?></p>
                    </div>
                <?php endif; ?>
            </div>
            <div class="content-bottom">
                <?php if (!empty($button_link)) : ?>
                    <div class="ct-button">
                        <a href="<?php echo esc_url($button_link);?>" target="_blank" class="btn"><?php echo esc_html($button_text);?></a>
                    </div>
                <?php endif; ?>
            </div>
        </div>
        <?php
    }

    function update($new_instance, $old_instance)
    {
        $instance = $old_instance;
        $instance['icon_img'] = strip_tags($new_instance['icon_img']);
        $instance['title'] = strip_tags($new_instance['title']);
        $instance['phone_text'] = strip_tags($new_instance['phone_text']);
        $instance['description'] = strip_tags($new_instance['description']);
        $instance['button_text'] = strip_tags($new_instance['button_text']);
        $instance['button_link'] = strip_tags($new_instance['button_link']);
        return $instance;
    }

    function form($instance)
    {
        $title = isset($instance['title']) ? esc_attr($instance['title']) : '';
        $phone_text = isset($instance['phone_text']) ? esc_attr($instance['phone_text']) : '';
        $description = isset($instance['description']) ? esc_attr($instance['description']) : '';
        $button_text = isset($instance['button_text']) ? esc_attr($instance['button_text']) : '';
        $button_link = isset($instance['button_link']) ? esc_attr($instance['button_link']) : '';
        $icon_img = isset($instance['icon_img']) ? esc_attr($instance['icon_img']) : '';
        ?>
        <p class="frontline-image-wrap">
            <label for="<?php echo esc_url($this->get_field_id('icon_img')); ?>"><?php esc_html_e('Icon Image', 'frontline'); ?></label>
            <input type="hidden" class="widefat hide-image-url"
                   id="<?php echo esc_attr($this->get_field_id('icon_img')); ?>"
                   name="<?php echo esc_attr($this->get_field_name('icon_img')); ?>"
                   value="<?php echo esc_attr($icon_img) ?>"/>
            <div class="frontline-show-image">
                <?php
                if ($icon_img != "") {
                    ?>
                    <img src="<?php echo wp_get_attachment_image_url($icon_img) ?>">
                    <?php
                }
                ?>
            </div>
            <?php
            if ($icon_img != "") {
                ?>
                <a href="#" class="frontline-select-image" style="display: none;"><?php esc_html_e('Select Image', 'frontline'); ?></a>
                <a href="#" class="frontline-remove-image"><?php esc_html_e('Remove Image', 'frontline'); ?></a>
                <?php
            } else {
                ?>
                <a href="#" class="frontline-select-image"><?php esc_html_e('Select Image', 'frontline'); ?></a>
                <a href="#" class="frontline-remove-image" style="display: none;"><?php esc_html_e('Remove Image', 'frontline'); ?></a>
                <?php
            }
            ?>
        </p>

        <p>
            <label for="<?php echo esc_url($this->get_field_id('title')); ?>"><?php esc_html_e('Title', 'frontline'); ?></label>
            <input class="widefat" id="<?php echo esc_attr( $this->get_field_id('title') ); ?>" name="<?php echo esc_attr( $this->get_field_name('title') ); ?>" type="text" value="<?php echo esc_attr( $title ); ?>" />
        </p>

        <p><label for="<?php echo esc_url($this->get_field_id('phone_text')); ?>"><?php esc_html_e( 'Phone Text', 'frontline' ); ?></label>
            <input class="widefat" id="<?php echo esc_attr( $this->get_field_id('phone_text') ); ?>" name="<?php echo esc_attr( $this->get_field_name('phone_text') ); ?>" type="text" value="<?php echo esc_attr( $phone_text ); ?>" /></p>
        <p>
            <label for="<?php echo esc_url($this->get_field_id('description')); ?>"><?php esc_html_e('Description', 'frontline'); ?></label>
            <input class="widefat" id="<?php echo esc_attr( $this->get_field_id('description') ); ?>" name="<?php echo esc_attr( $this->get_field_name('description') ); ?>" type="text" value="<?php echo esc_attr( $description ); ?>" />
        </p>

        <p><label for="<?php echo esc_attr($this->get_field_id('button_text')); ?>"><?php esc_html_e( 'Button Text', 'frontline' ); ?></label>
            <input class="widefat" id="<?php echo esc_attr( $this->get_field_id('button_text') ); ?>" name="<?php echo esc_attr( $this->get_field_name('button_text') ); ?>" type="text" value="<?php echo esc_attr( $button_text ); ?>" /></p>

        <p><label for="<?php echo esc_attr($this->get_field_id('button_link')); ?>"><?php esc_html_e( 'Button Link', 'frontline' ); ?></label>
            <input class="widefat" id="<?php echo esc_attr( $this->get_field_id('button_link') ); ?>" name="<?php echo esc_attr( $this->get_field_name('button_link') ); ?>" type="text" value="<?php echo esc_attr( $button_link ); ?>" /></p>
        <?php
    }

}

function register_contact_phone_widget()
{
    global $wp_widget_factory;
    $wp_widget_factory->register( 'CMS_contact_phone_Widget' );
}

add_action('widgets_init', 'register_contact_phone_widget'); ?>